C	RDLUMP.FOR
C
C	READS IN CONTROL PARAMETERS DEFINING MODEL SPECIES AND HOW
C	THEY ARE LUMPED.
C
C	ASKS FOR LUMPING PARAMETER FILE NAME, OPENS IT, AND READS
C	PARMS FROM IT, OPENING AND READING PARM FILES REFERENCED BY
C	IT.
C
C	SUBROUTINES CALLED (ALL TO READ KINETIC AND MECHANISTIC
C	PARAMETERS FOR THE DETAILED MODEL SPECIES)
C		RDGENP	READS PARMS IN "GENERAL", OR "AROMATIC"
C			FORMAT.
C		RDALKP	READS PARMS IN FORMAT OUTPUT BY "ALKANE"
C			PROGRAM
C		RDOLEP	READS PARMS IN "ALKENE" FORMAT
C		RDGN2P	READS PARMS IN ".GEN" GENERAL FORMAT.  FOR
C			4-BYTE PARAMETER NAMES.
C
C	ARGUMENTS:
C		IN1	UNIT NO. TO READ LUMPING CONTROL FILE.  IF
C			NEGATIVE, IT IS ALREADY OPEN, OTHERWISE, PGM
C			ASKS FOR NAME OF FILE.   CLOSED WHEN DONE.]
C		IUNIT2	UNIT NO.  AVAILABLE FOR USE.  MUST BE CLOSED
C			INITIALLY, CLOSED WHEN DONE
C		IKODE	USED TO CONTROL INITIALIZATION:
C			IKODE=<0:  TEMPR, PREFIX TO BE READ FROM LPC
C				   FILE.  (PREPEMIT MODE)
C			IKODE=1:   TEMPR, PREFIX ASSUMED TO BE ALREADY
C				   INITIALIZED, BUT CAN BE CHANGED BY LPC
C				   FILE
C			IKODE=>2:  TEMPR, PREFIX ASSUMED TO BE DEFINED, AND
C				   CANNOT BE CHANGED BY LPC FILE (LUMPINT
C				   MODE)
C			IKODE=3	   CALLED BY LUMPINT.  FORCES OUTRXN=T IF
C				   GENERAL FORMAT CODE "0" USED.
C	NOTE: UNIT 9 USED FOR TEMPORARY INPUT
C
	SUBROUTINE RDLUMP (IN1,IUNIT2,IKODE)
C
C
	INTEGER IN1,IUNIT1,IUNIT2
C
C	COMMON SPECIFICATIONS
C
	INCLUDE 'LUMPSPEC.FOR'
C
C	LOCAL SPECIFICATIONS:
C
C	LIST OF GROUP ID'S USED FOR MODEL SPECIES.  USED TO CHECK
C	TO MAKE SURE AT LEAST ONE GROUP IS DEFINED FOR EACH
C
	PARAMETER (MAXINP=20)
	INTEGER NGRPIN,GRPINP(MAXINP)
	LOGICAL ERRIND
C
C
	INTEGER TSTKOD
	CHARACTER FILNAM*80,INLIN*80,LPCFIL*60,NAMEIN*8,MIXID*8,CMPUIC*40
	DATA CMPUIC/'?'/
C
C
	LMECUC=LNBLNK(MECUIC)
C
C	INITIALIZE OUTPUT FORMAT VARIABLES
C
	IF (IKODE.LE.0) THEN
		LPRE=0
		LPRECH=' '
	ENDIF
	INTFMT=.FALSE.
	SHORT=.TRUE.
	NAMEOK=.TRUE.
	TOPPM=.TRUE.
C
C	"TSTKOD" USED TO INDICATE WHETHER LUMPED GROUP IS FOR
C	REACTIVITY TEST COMPOUNDS ONLY.  0 = "BASE" (DEFAULT),
C	1 = "TEST".  "GROUP=TEST" INPUT CAUSES ALL GROUPS TO BE
C	"TEST" TYPE.  "GROUP=BASE" INPUT RETURNS TO DEFAULT FOR
C	SUBSEQUENT GROUPS.
C
	TSTKOD=0
C
C	MARK INTEGRATED OH AS UNDEFINED
C
	INTOH=1.0E+20
C
C	INITIALIZE TEMPERATURE, NO. GROUPS, MODEL SPECIES
C	(NOTE: THE SPECIAL LUMPED GROUP "NROG") IS USED FOR ALL SPECIES WITH
C	KOH < KOHMIN FOR ITS GROUP ID)
C
	IF (IKODE.LE.0) THEN
		TEMPR=300.0
		THIGH=330.0
		TLOW=270.0
	ENDIF
	RTEMP=0.0019872*TEMPR
        CTEMP=4.40373E+17/TEMPR
	TOV300=TEMPR/300.0
C
C	ATM IS PRESSURE READ FROM PARM FILES (IF ANY)
C
	ATM=0.0
C
	NAAPRM=0
	NAA=0
C
	NSUB=0
	NMODSP=0
	NMIXS=0
	MIXI2=1
C
	NGRP=1
	NGRPIN=0
	GRPNAM(1)='NROG'
	GRPPNM(1)='  '
	GRPTYP(1)=0
C
C	GET PARM FILE NAME, OPEN IT, AND PROCESS PARMS
C	FORMAT OF PARM FILE:  INPUT RECORDS CAN BE IN ANY ORDER,
C	COMMANDS ARE "TEMP", "PARM", "GROUP", AND "REPLACE".
C
	IF (IN1.LT.0) THEN
		IUNIT1=-IN1
	ELSE
		IUNIT1=IN1
 100		WRITE (ICRT,102)
 102		FORMAT (' File name for control parms (<CR> to end): ')
		READ (IKEY,'(A)',END=9900) LPCFIL
		OPEN (UNIT=IUNIT1,FILE=LPCFIL,STATUS='OLD',ERR=100) ! readonly
	ENDIF
C
C	PROCESS LUMPING CONTROL INPUT
C
 110	READ (IUNIT1,'(A)',END=180) INLIN
	IF (INLIN(1:1).EQ.'!') GOTO 110
	IF (INLIN(1:1).EQ.' ') GOTO 110
C
	IF (INLIN(1:4).EQ.'TEMP') THEN
C
C		TEMP temp		temp=TEMPERATURE IN K ("TEMP",G10.3)
C
		IF (IKODE.LE.1) THEN
			IF (NAA.NE.0) THEN
				WRITE (ICRT,*) 'Can''t change T ',
     &				 'after parms input'
				CALL EXIT (2)
			ENDIF
			CALL PARSE0 (2,INLIN,80)
			CALL PARSER (2,TEMPR,ERRIND,INLIN)
			IF (ERRIND) GOTO 9100
			IF (TEMPR.LE.0.0) GOTO 9100
		        RTEMP=0.0019872*TEMPR
		        CTEMP=4.40373E+17/TEMPR
			TOV300=TEMPR/300.0
		ENDIF
C
	ELSEIF (INLIN(1:5).EQ.'INTOH') THEN
C
C		INTOH x			x = INTEGRATED OH CONCENTRATION,
C					IN PPT-MIN
C
		READ (INLIN,'(5X,G15.0)',ERR=9100) INTOH
		INTOH=INTOH*1.0E-6
C					
C
	ELSEIF (INLIN(1:8).EQ.'NORENAME') THEN
C
C		NORENAME		DO NOT INCLUDE .NAME STATEMENT IN
C					OUTPUT FILE
C
		NAMEOK=.FALSE.
C
	ELSEIF (INLIN(1:4).EQ.'PARM') THEN
C
C		PARM g f filename	g=LUMPED GROUP ID FOR ALL MODEL
C					SPECIES FROM THIS FILE; f = FILE 
C					FORMAT; filename = NAME OF FILE TO
C					READ SPECIES AND PARMS
C					("PARM",1X,A1,1X,A40)
C
		READ (INLIN,'(5X,2(I1,1X),A60)',ERR=9100) IGRP,KODE,
     &		 FILNAM
		IF (MECUIC(1:1).EQ.' ') THEN
			INLIN=FILNAM
		ELSE
			INLIN=MECUIC(1:LMECUC)//FILNAM
		ENDIF
		OPEN (UNIT=IUNIT2,FILE=INLIN,STATUS='OLD',ERR=9200)
c							! readonly
		I1=NAA+1
C
C		FILE HAS CODE TELLING WHAT FORMAT:  1 = GENERAL
C		("AROMATIC"); 2 = "ALKANE"; 3 = "ALKENE";
C		0 = GENERAL FOR .GEN
C
		IF (KODE.EQ.1) THEN
			CALL RDGENP (IUNIT2)
		ELSEIF (KODE.EQ.2) THEN
			CALL RDALKP (IUNIT2)
		ELSEIF (KODE.EQ.3) THEN
			CALL RDOLEP (IUNIT2)
		ELSEIF (KODE.EQ.0) THEN
			IF (IKODE.EQ.3) OUTRXN=.TRUE.
			CALL RDGN2P (IUNIT2)
		ELSE
			GOTO 9300
		ENDIF
C
C		INDICATE THE GROUP ID OF THE SPECIES JUST READ IN
C
		DO 120 I=I1,NAA
  120		AAGRP(I)=IGRP
C
		IF (NGRPIN.EQ.MAXINP) THEN
			WRITE (ICRT,*) 'INCREASE MAXINP IN RDLUMP'
			CALL EXIT (2)
		ENDIF
		NGRPIN=NGRPIN+1
		GRPINP(NGRPIN)=IGRP
C
	ELSEIF (INLIN(1:10).EQ.'GROUP=TEST') THEN
C
C		GROUP=TEST		SUBSEQUENT GROUPS INPUT ARE
C					FOR REACTIVITY TEST ONLY.
C
		TSTKOD=1
C
	ELSEIF (INLIN(1:10).EQ.'GROUP=BASE') THEN
C
C		GROUP=BASE		SUBSEQUENT GROUPS INPUT ARE NORMAL
C					("BASE") GROUPS.  (RESTORES DEFAULT)
C
		TSTKOD=0
C
	ELSEIF (INLIN(1:5).EQ.'GROUP') THEN
C
C
C		GROUP g name pn i kohmin kohdef|aohdef bohdef eaohdef
C					g=LUMPED GROUP ID; name = LUMPED GROUP
C					NAME; pn = LUMPED GROUP PARM NAME;
C					i = AVERAGING INDICATOR (0 = SIMPLE,
C					1 = USE INTOH, 2 = WEIGH BY KOH);
C					3 = USE INTOH FOR DMS THAT REACT SLOWER
C					THAN DEFAULT, WEIGH OTHERS EQUALLY.
C					kohmin = MINIMUM KOH IN GROUP
C					kohdef = KOH TO USE FOR THE GROUP
C					IF "WEIGHED" AVERAGING DONE
C					aohdef,bohdef,eaohdef = T-DEPENDENCE
C					OF DEFAULT KOH.
C
		IF (NGRP.EQ.MAXGRP) THEN
			WRITE (ICRT,*) 'INCREASE MAXGRP IN LUMPSPEC'
			CALL EXIT (2)
		ENDIF
		NGRP=NGRP+1
C
C		READ (INLIN,'(6X,I1,1X,A4,1X,A2,1X,I1,4E10.2)',ERR=9100)
C     &		 GRPTYP(NGRP),GRPNAM(NGRP),GRPPNM(NGRP),GRPIND(NGRP),
C     &		 KOHMIN(NGRP),DRKGRP(NGRP),DEAGRP(NGRP),DBGRP(NGRP)
C
		CALL PARSE0 (9,INLIN,80)
		CALL PARSEI (2,GRPTYP(NGRP),ERRIND,INLIN)
		IF (ERRIND) GOTO 9100
		IF (GRPTYP(NGRP).EQ.0) GOTO 9100
C
		CALL PARSE1 (3,GRPNAM(NGRP),I,4,INLIN)
		CALL PARSE1 (4,GRPPNM(NGRP),I,2,INLIN)
		CALL PARSI2 (5,GRPIND(NGRP),0,ERRIND,INLIN)
		IF (ERRIND) GOTO 9100
		CALL PARSR2 (6,KOHMIN(NGRP),0.0,ERRIND,INLIN)
		IF (ERRIND) GOTO 9100
C
C		DEFAULT KOH IGNORED IF "SIMPLE" AVERAGING DONE.
C		IF "WEIGHED" AVERAGING DONE, THEN RKGRP INPUT IS
C		USED FOR THE RATE CONTANT, UNLESS NO RKGRP INPUT
C		GIVEN.  CALCULATE T-DEPENDENCE OF DEFAULT KOH, 
C		IF APPLICABLE.  
C
		IF (GRPIND(NGRP).EQ.0) THEN
			DRKGRP(NGRP)=0.0
			DAGRP(NGRP)=0.0
			DEAGRP(NGRP)=0.0
			DBGRP(NGRP)=0.0
		ELSE
			CALL PARSR2 (7,A,0.0,ERRIND,INLIN)
			IF (ERRIND) GOTO 9100
			IF (A.NE.0.0) THEN
				CALL PARSR2 (8,EA,0.0,ERRIND,INLIN)
				IF (ERRIND) GOTO 9100
				CALL PARSR2 (9,B,0.0,ERRIND,INLIN)
				IF (ERRIND) GOTO 9100
				DRKGRP(NGRP)=A*EXP(-EA/RTEMP)*
     &				 ((TOV300)**B)
				DAGRP(NGRP)=A
				DEAGRP(NGRP)=EA
				DBGRP(NGRP)=B
			ELSE
				DRKGRP(NGRP)=0.0
				DAGRP(NGRP)=0.0
				DEAGRP(NGRP)=0.0
				DBGRP(NGRP)=0.0
			ENDIF
		ENDIF
C
C		MARK THIS GROUP AS BASE OR TEST, DEPENDING ON LAST
C		"GROUP=TEST" OR "GROUP=BASE" RECORD INPUT
C
		IF (TSTKOD.NE.0) GRPTYP(NGRP)=-GRPTYP(NGRP)
C
C
	ELSEIF (INLIN(1:7).EQ.'REPLACE') THEN
C
C		REPLACE filename	filename = NAME OF FILE TO READ
C					MODEL SPECIES REPLACEMENT OR "LUMPED
C					MOLECULE" INFORMATION.  IF filename
C					IS BLANK, READS THIS INFO FROM THIS
C					FILE UNTIL 'END' RECORD ENCOUNTERED.
C
		READ (INLIN,'(8X,A60)',ERR=9100) FILNAM
		IF (FILNAM(1:1).EQ.' ') THEN
			IUNIT=IUNIT1
		ELSE
			IF (MECUIC(1:1).EQ.' ') THEN
				INLIN=FILNAM
			ELSE
				INLIN=MECUIC(1:LMECUC)//FILNAM
			ENDIF
			OPEN (UNIT=IUNIT2,FILE=INLIN,STATUS='OLD',
     &			 ERR=9200)	! readonly
			IUNIT=IUNIT2
		ENDIF
C
  130		READ (IUNIT,'(A)',END=138) INLIN
		IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 130
		IF (INLIN(1:4).EQ.'END ') GOTO 110
		IF (NSUB.EQ.MAXSUB) THEN
			WRITE (ICRT,*) 'INCREASE MAXSUB IN LUMPSPEC'
			CALL EXIT (2)
		ENDIF
		NSUB=NSUB+1
		CALL PARSE0 (10,INLIN,80)
		CALL PARSE1 (1,SUBNAM(NSUB),I,8,INLIN)
		CALL PARSE1 (2,SUBOUT(NSUB),I,8,INLIN)
		CALL PARSER (3,SUBFAC(NSUB),ERRIND,INLIN)
		CALL PARSE1 (4,NAMEIN,I,8,INLIN)
		IF (SUBNAM(NSUB).EQ.SUBOUT(NSUB)) THEN
			NSUB=NSUB-1
			GOTO 130
		ELSEIF (ERRIND) THEN
			SUBFAC(NSUB)=1.0
		ELSEIF (NAMEIN(1:1).NE.' ') THEN
C			- PROCESS MIXTURE
C			- NOTE:  MAXIMUM OF 4 COMPONENTS PER MIXTURE ALLOWED
			IF (NMIXS.EQ.MAXMIX) THEN
				WRITE (ICRT,*)
     &				 'INCREASE MAXMIX IN LUMPSPEC'
				CALL EXIT (2)
			ENDIF
			NMIXS=NMIXS+1
			MIXNAM(NMIXS)=SUBNAM(NSUB)
			MIXI1(NMIXS)=MIXI2
			IF (MIXI2+1.GT.MAXMXS) GOTO 1309
			CALL PARSER (5,F,ERRIND,INLIN)
			IF (ERRIND.OR.F.EQ.0.0) GOTO 1308
			MIXCMP(MIXI2)=SUBOUT(NSUB)
			MIXFAC(MIXI2)=SUBFAC(NSUB)
			MIXI2=MIXI2+1
			MIXCMP(MIXI2)=NAMEIN
			MIXFAC(MIXI2)=F
			MIXI2=MIXI2+1
			TOTF=SUBFAC(NSUB)+F
			NSUB=NSUB-1
			J=6
  132			CALL PARSE1 (J,NAMEIN,I,8,INLIN)
			IF (NAMEIN(1:1).NE.' ') THEN
				IF (J.EQ.10) THEN
					IF (NAMEIN(1:1).EQ.'&') THEN
						READ (IUNIT,'(A)',END=1308) INLIN
						IF (INLIN(1:1).NE.' ') GOTO 1308
						INLIN=INLIN(2:)
						CALL PARSE0 (10,INLIN,80)
						CALL PARSE1 (1,NAMEIN,I,8,INLIN)
						J=1
					ELSE
						WRITE (ICRT,*)
     &					 'NO MORE THAN 4 CMPS PER LINE'
						GOTO 1308
					ENDIF
				ELSEIF (MIXI2.GT.MAXMXS) THEN
					GOTO 1309
				ENDIF
				CALL PARSER (J+1,F,ERRIND,INLIN)
				IF (ERRIND.OR.F.EQ.0.0) GOTO 1308
				TOTF=TOTF+F
				MIXCMP(MIXI2)=NAMEIN
				MIXFAC(MIXI2)=F
				MIXI2=MIXI2+1
				J=J+2
				GOTO 132
			ENDIF
			NMIXI(NMIXS)=MIXI2-MIXI1(NMIXS)
			MIXMOL(NMIXS)=TOTF
		ELSEIF (SUBNAM(NSUB).EQ.SUBOUT(NSUB)) THEN
			NSUB=NSUB-1
		ENDIF
		GOTO 130
 1308		WRITE (ICRT,*) 'Error processing REPLACE for mixtures.'
		WRITE (ICRT,*) 'Bad record: ',INLIN(1:LNBLNK(INLIN))
		CALL EXIT (2)
 1309		WRITE (ICRT,*) 'INCREASE MAXMXS IN LUMPSPEC'
		CALL EXIT (2)
C
  138		IF (IUNIT.EQ.IUNIT1) GOTO 180
		CLOSE (UNIT=IUNIT)
C
C
	ELSEIF (INLIN(1:7).EQ.'MIXDEF ') THEN
C
C		MIXDEF filename	filename = NAME OF FILE TO READ .CMP
C					FILES DEFINING DMS MIXTURES.  IF filename
C					IS BLANK, READS THIS INFO FROM THIS
C					FILE UNTIL 'END' RECORD ENCOUNTERED.
C
C
		READ (INLIN,'(7X,A60)',ERR=9100) FILNAM
		IF (FILNAM(1:1).EQ.' ') THEN
			IUNIT=IUNIT1
		ELSE
			IF (MECUIC(1:1).EQ.' ') THEN
				INLIN=FILNAM
			ELSE
				INLIN=MECUIC(1:LMECUC)//FILNAM
			ENDIF
			OPEN (UNIT=IUNIT2,FILE=INLIN,STATUS='OLD',
     &			 ERR=9200)	! readonly
			IUNIT=IUNIT2
		ENDIF
C
		IF (CMPUIC(1:1).EQ.'?') THEN
			OPEN (UNIT=9,FILE=MECUIC(1:LMECUC)//'MODELING.PRM'
     &		 ,STATUS='UNKNOWN',ERR=1313)	! readonly
			CMPUIC=MECUIC
 1311			READ (9,'(A)',END=1312) INLIN
			IF (INLIN(1:4).EQ.'CMP=') CMPUIC=MECUIC(1:LMECUC)//INLIN(5:)
			GOTO 1311
 1312			CLOSE (UNIT=9)
 1313			CONTINUE
		ENDIF
C
  131		READ (IUNIT,'(A)',END=1381) INLIN
		IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') THEN
			GOTO 131
		ELSEIF (INLIN(1:4).EQ.'END ') THEN
			GOTO 110
		ENDIF
		CALL PARSE0 (2,INLIN,80)
		CALL PARSE1 (1,MIXID,I,8,INLIN)
		CALL PARSE1 (2,NAMEIN,I,8,INLIN)
		IF (NMIXS.EQ.MAXMIX) THEN
			WRITE (ICRT,*) 'INCREASE MAXMIX IN LUMPSPEC'
			CALL EXIT (2)
		ENDIF
		NMIXS=NMIXS+1
		MIXNAM(NMIXS)=MIXID
		MIXI1(NMIXS)=MIXI2
		MIXI1A=MIXI2
		TOTF=0.0
C
		OPEN (UNIT=9,FILE=CMPUIC(1:LNBLNK(CMPUIC))
     &		 //NAMEIN(1:I)//'.CMP',STATUS='OLD',ERR=1317)
C						! readonly
C
C		READ COMPOSITION FILE.  REPLACE BY SUBSTITUTIONS, IF ANY
C		THEN ADD TO PREVIOUS INPUT FOR SAME DMS.
C
 1314		READ (9,'(A)',END=1315) INLIN
			IF (INLIN(1:1).EQ.'!') GOTO 1314
			CALL PARSE0 (2,INLIN,80)
			CALL PARSE1 (1,NAMEIN,I,8,INLIN)
			IF (NAMEIN(1:1).EQ.' ') GOTO 1314
			CALL PARSER (2,F,ERRIND,INLIN)
			IF (ERRIND) GOTO 1318
			IF (F.EQ.0.0) GOTO 1314
 1331			DO 1332 I=1,NSUB
			IF (NAMEIN.EQ.SUBNAM(I)) THEN
				NAMEIN=SUBOUT(I)
				F=F*SUBFAC(I)
				GOTO 1331
			ENDIF
 1332			CONTINUE
C
			DO 1333 IMIX=1,NMIXS-1
			IF (MIXNAM(IMIX).EQ.NAMEIN) THEN
				DO 1334 I=MIXI1(IMIX),MIXI1(IMIX)+NMIXI(IMIX)-1
				    DO 1336 J=MIXI1A,MIXI2
					IF (MIXCMP(I).EQ.MIXCMP(J)) THEN
						MIXFAC(J)=MIXFAC(J)+(F*MIXFAC(I))
						TOTF=TOTF+(F*MIXFAC(I))
						GOTO 1334
					ENDIF
 1336				    CONTINUE
				    IF (MIXI2+1.GT.MAXMXS) GOTO 1319
				    MIXCMP(MIXI2)=MIXCMP(I)
				    MIXFAC(MIXI2)=F*MIXFAC(I)
				    TOTF=TOTF+(F*MIXFAC(I))
				    MIXI2=MIXI2+1
 1334				CONTINUE
				GOTO 1314
			ENDIF
 1333			CONTINUE
C
			DO 1337 J=MIXI1A,MIXI2
				IF (NAMEIN.EQ.MIXCMP(J)) THEN
					MIXFAC(J)=MIXFAC(J)+F
					TOTF=TOTF+F
					GOTO 1314
				ENDIF
 1337			CONTINUE
			IF (MIXI2+1.GT.MAXMXS) GOTO 1319
			MIXCMP(MIXI2)=NAMEIN
			MIXFAC(MIXI2)=F
			MIXI2=MIXI2+1
			TOTF=TOTF+F
			GOTO 1314
 1315		CLOSE (UNIT=9)
C
		NMIXI(NMIXS)=MIXI2-MIXI1(NMIXS)
		MIXMOL(NMIXS)=TOTF
		GOTO 131
 1317		WRITE (ICRT,*) 'File = ',CMPUIC(1:LNBLNK(CMPUIC))
     &		 //NAMEIN(1:I)//'.CMP does not exist.'
		CALL EXIT (2)
 1318		WRITE (ICRT,*) 'Error processing mixture for '//MIXID
		WRITE (ICRT,*) 'Bad record: '//INLIN(1:LNBLNK(INLIN))
		CALL EXIT (2)
 1319		WRITE (ICRT,*) 'INCREASE MAXMXS IN LUMPSPEC'
		CALL EXIT (2)
C
 1381		IF (IUNIT.EQ.IUNIT1) GOTO 180
		CLOSE (UNIT=IUNIT)
C
C
C
	ELSEIF (INLIN(1:7).EQ.'SPECIES') THEN
C
C		SPECIES filename	filename = NAME OF FILE TO READ
C					MODEL SPECIES NAMES AND NUMBER OF
C					CARBONS FOR EACH.  IF filename IS
C					BLANK, READS THIS INFO FROM THIS
C					FILE UNTIL 'END' RECORD READ
C
		READ (INLIN,'(8X,A60)',ERR=9100) FILNAM
		IF (FILNAM(1:1).EQ.' ') THEN
			IUNIT=IUNIT1
		ELSE
			IF (MECUIC(1:1).EQ.' ') THEN
				INLIN=FILNAM
			ELSE
				INLIN=MECUIC(1:LMECUC)//FILNAM
			ENDIF
			OPEN (UNIT=IUNIT2,FILE=INLIN,STATUS='OLD',
     &			 ERR=9200)	! readonly
			IUNIT=IUNIT2
		ENDIF
C
  140		READ (IUNIT,'(A)',END=148) INLIN
		IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 140
		IF (INLIN(1:4).EQ.'END ') GOTO 110
C
		NMODSP=NMODSP+1
		IF (NMODSP.GT.MMODSP) THEN
			WRITE (ICRT,*) 'INCREASE NMODSP IN LUMPSPEC'
			CALL EXIT (2)
		ENDIF
                CALL PARSE0 (6,INLIN,80)
                CALL PARSE1 (1,MODSP(NMODSP),I,8,INLIN)
                CALL PARSI2 (2,MODNC(NMODSP),1,ERRIND,INLIN)
                IF (ERRIND) GOTO 9100
                CALL PARSR2 (3,MODMW(NMODSP),0.0,ERRIND,INLIN)
                IF (ERRIND) GOTO 9100
                CALL PARSR2 (4,A,0.0,ERRIND,INLIN)
                IF (ERRIND) GOTO 9100
                CALL PARSR2 (5,EA,0.0,ERRIND,INLIN)
                IF (ERRIND) GOTO 9100
                CALL PARSR2 (6,B,0.0,ERRIND,INLIN)
                IF (ERRIND) GOTO 9100
		MODKOH(NMODSP)=CTEMP*A*(TOV300**B)*EXP(-EA/RTEMP)
		GOTO 140
C
  148		IF (IUNIT.EQ.IUNIT1) GOTO 180
		CLOSE (UNIT=IUNIT)
C
C
	ELSEIF (INLIN(1:6).EQ.'INTFMT') THEN
C
C		INTFMT		OUTPUT FORMATTED SO IT CAN BE READ
C				BY SAPRC INT PROGRAM (NOT USED FOR
C				AIRSHED MODEL PREPARATIONS)
C
		INTFMT=.TRUE.
C
C
	ELSEIF (INLIN(1:6).EQ.'PREFIX') THEN
C
C		PREFIX prefix	4-CHAR (MAX) PREFIX FOR OUTPUT MODEL
C				SPECIES NAMES.  (FOR USE WITH SAPRC
C				INT PROGRAM ONLY.  NOT FOR AIRSHED
C				MODEL PREPARATIONS.)
C
		IF (IKODE.LE.1) THEN
			IF (INLIN(8:8).EQ.' ') THEN
				GOTO 9100
			ELSEIF (INLIN(9:9).EQ.' ') THEN
				LPRE=1
			ELSEIF (INLIN(10:10).EQ.' ') THEN
				LPRE=2
			ELSEIF (INLIN(11:11).EQ.' ') THEN
				LPRE=3
			ELSE
				LPRE=4
			ENDIF
			LPRECH=INLIN(8:11)
		ENDIF
C
C
	ELSEIF (INLIN(1:7).EQ.'NOSHORT') THEN
C
C		NOSHORT		(FOR USE WITH LUMPINT.)  PREVENTS
C				CONDENSATION OF LUMPED GROUPS.
C				IGNORED WHEN LUMPING EMISSIONS.
C
		SHORT=.FALSE.
C
C
	ELSEIF (INLIN(1:6).EQ.'FIXKOH') THEN
C
C		FIXKOH dmsname kOH
C				FORCES DMS ALREADY READ IN TO HAVE
C				A SPECIFIED KOH.  USEFUL MAINLY TO
C				FORCE MOLAR LUMPING FOR SPECIFIED
C				SPECIES IN GROUPS USING REACTIVITY
C				WEIGHTING, BY GIVING A DMS THE SAME
C				KOH AS SPECIFIED FOR THE LUMPED GROUP.
C
		IF (NAA.EQ.0) THEN
			WRITE (ICRT,*) 'FIXKOH input given before any',
     &			 ' PARM input.'
			GOTO 9900
		ENDIF
C
		CALL PARSE0 (3,INLIN,80)
		CALL PARSE1 (2,NAMEIN,I,8,INLIN)
		DO 152 I=1,NAA
		IF (AANAM(I).EQ.NAMEIN) THEN
			CALL PARSER (3,AAKOH(I),ERRIND,INLIN)
			IF (ERRIND) GOTO 9100
			GOTO 110
		ENDIF
  152		CONTINUE
		WRITE (ICRT,*) 'FIXKOH given for unrecognized speci',
     &		 'es = "',NAMEIN,'"'
		GOTO 9900
C
C
	ELSEIF (INLIN(1:5).EQ.'THIGH') THEN
C
C		THIGH, TLOW = TEMP'S USED TO CALCULATE ARRHENIUS
C		PARAMETERS, IF APPLICABLE.  IGNORED IF TEMP NOT
C		BETWEEN THIGH AND TLOW.
C
		IF (NAA.NE.0) THEN
			WRITE (ICRT,*) 'Can''t change Thigh ',
     &			 'after parms input'
			CALL EXIT (2)
		ENDIF
		CALL PARSE0 (2,INLIN,80)
		CALL PARSER (2,THIGH,ERRIND,INLIN)
		IF (ERRIND) GOTO 9100
		IF (THIGH.LE.TEMPR.OR.(THIGH.LE.TLOW)) THEN
			THIGH=0.0
			TLOW=0.0
		ENDIF
C
	ELSEIF (INLIN(1:4).EQ.'TLOW') THEN
C
		IF (NAA.NE.0) THEN
			WRITE (ICRT,*) 'Can''t change Tlow ',
     &			 'after parms input'
			CALL EXIT (2)
		ENDIF
C
		CALL PARSE0 (2,INLIN,80)
		CALL PARSER (2,TLOW,ERRIND,INLIN)
		IF (ERRIND) GOTO 9100
		IF (TLOW.GE.TEMPR.OR.(THIGH.NE.0.0.AND.TLOW.GE.THIGH))
     &		 THEN
			THIGH=0.0
			TLOW=0.0
		ENDIF
C
	ELSEIF (INLIN(1:6).EQ.'NOPPM ') THEN
		TOPPM=.FALSE.
	ELSEIF (INLIN(1:6).EQ.'TOPPM ') THEN
		TOPPM=.TRUE.
C
	ELSE
C
C		UNRECOGNIZED LUMPING CONTROL COMMAND
C
		GOTO 9100
	ENDIF
C
C	LOOP BACK FOR NEXT LUMPING CONTROL COMMAND
C
	GOTO 110
C
C	END OF LUMPING CONTROL INPUT
C
  180	CLOSE (UNIT=IUNIT1)
	IF (IN1.GT.0) WRITE (ICRT,182) NSUB,NAA
  182	FORMAT (' Parameters for',I4,' substitutions and',
     &   I4,' model species read.')
C
C	MAKE SURE ALL TYPE ID'S HAVE AT LEAST ONE GROUP DEFINED FOR
C	IT
C
	DO 190 I=1,NGRPIN
	DO 192 J=1,NGRP
	IF (GRPINP(I).EQ.IABS(GRPTYP(J))) GOTO 190
  192	CONTINUE
	WRITE (ICRT,'('' No group defined for type ='',I2)') GRPINP(I)
  190	CONTINUE
C
C
C	MODIFY GRPIND'S (IF APPROPRIATE) BASED ON INTOH INPUT
C	IF INTOH NOT DEFINED (INDICATED BY IT HAVING A VALUE OF
C	1.E20), AND GRPIND'S INDICATE IT MAY BE NEEDED, READ
C	IT IN HERE.  NEGATIVE INTOH VALUE INDICATES LARGE INTEGRATED
C	OH, SO ALL REACTED AND WEIGHED BY AMOUNT PRESENT ONLY.  ZERO
C	VALUE INDICATES AMOUNT REACTED PROPORTIONAL TO OH. 
C
C	ONLY READ IN INTOH IF IN1>0 -- I.E., IF THERE'S ALREADY
C	USER INTERACTION EXPECTED.  IF IN1<0 AND INTOH NOT DEFINED,
C	OUTPUT WARNING AND SET IT TO ZERO.
C
	DO 194 I=1,NGRP
	IF (GRPIND(I).EQ.1) THEN
		IF (INTOH.EQ.1.0E+20) THEN
		    IF (IN1.GT.0) THEN
  195			WRITE (ICRT,196)
  196			FORMAT (/' Give integrated OH in ppt-min.',
     &                   '  (50 is typical, negative = infinite.)'
     &                   /'$IntOH (ppt-min) = ')
			READ (ICRT,*,END=9900,ERR=195) INTOH
			INTOH=INTOH*1.0E-6
		    ELSE
			WRITE (ICRT,*) 'Warning.  INTOH is undefined.'
			INTOH=0.0
		    ENDIF
		ENDIF
		IF (INTOH.LT.0.0) THEN
			GRPIND(I)=0
		ELSEIF (INTOH.EQ.0.0) THEN
			GRPIND(I)=2
		ENDIF
	ELSEIF (GRPIND(I).EQ.3.AND.DRKGRP(I).EQ.0.0) THEN
		WRITE (ICRT,*) 'No Default kOH given for Type 3 lumping for',
     &	 ' group = ',GRPNAM(I)
		WRITE (ICRT,*) 'Set to simple IntOH weighing'
		GRPIND(I)=1
	ENDIF
  194	CONTINUE
C
	IF (THIGH.EQ.0.0) TLOW=0.0
	IF (TLOW.EQ.0.0) THIGH=0.0
C
	RETURN
C
C
C	ERRORS
C
 9100	WRITE (ICRT,*) 'ERROR READING DATA FROM LUMPING CONTROL FILE:'
	WRITE (ICRT,*) 'Bad line = "',INLIN(1:LNBLNK(INLIN)),'"'
	GOTO 9900
 9200	WRITE (ICRT,*) 'ERROR OPENING LUMPING PARM FILE = ',
     &	 INLIN(1:LNBLNK(INLIN))
	GOTO 9900
 9300	WRITE (ICRT,*) 'BAD FORMAT CODE GIVEN FOR LUMPING FILE = ',
     &	 FILNAM
C	GOTO 9900
C 9400	WRITE (ICRT,*) 'BAD DATA IN REPLACE INPUT'
C	IF (FILNAM(1:1).NE.' ') WRITE (ICRT,*) 'FROM FILE = ',FILNAM
C
C	DONE
C
 9900	WRITE (ICRT,*) 'PROGRAM ABORTED.'
	CALL EXIT (2)
	END
C
C	RETURNS .LPC TYPE
C
	SUBROUTINE LPCTYP (KODE)
	CHARACTER KODE*3
	KODE='LPC'
	RETURN
	END
