C	LUMPGEN.FOR
C
C	PROGRAM TO PRE-PROCESS "INT" FILES FOR FIXED PARAMETER LUMPING.
C
C	PROGRAM INFO. PASSED THROUGH COMMAND LUNE.  MUST BE
C	INVOKED BY
C
C		"LUMPGEN infile outfile [parmfile]"
C	WHERE
C	infile =	INPUT FILE (FULL NAME)
C	outfile =	OUTPUT FILE
C	parmfile =	PARAMETER FILE.  IF NOT INPUT, USES MODELING.PRM
C			(W/O EXTENSTION.)  IF NO .PRM FILE, USED FOR
C			.LCC FILE.
C
C	PARAMETERS USED:
C
C	DFLMOD:		DEFAULT MODEL USED.  
C			MODEL USED FOR VARYSD PROCESSING
C			AND OUTPUT IN MODEL= RECORD REGARDLESS OF LUMPING.
C	LCC:		USES lccfile.LCC AS LUMPING CONTROL FILE
C			IF NOT SPECIFIED, THEN LUMPING NOT ALLOWED.
C
C	(USED IF VARYSD INPUT ONLY)
C
C	VSD:		VDS UIC
C	MOD:		MODEL UIC
C
C
C	CALLS:
C		RDLUMP	SUBROUTINE TO READ LUMPING CONTROL FILE
C
C		GENLMP	LUMPING SUBROUTINE FOR COMPOSITION INPUT
C
C		LMPSUB	CALCULATES LUMPED SPECIES LEVELS AND 
C			PARAMETERS FROM DETAILED MODEL SPECIES
C			COMPOSITIONS (FOR EMISSIONS PROCESSING)
C		VSDSUB	FOR VARYSD PROCESSING, IF A #VARYSD=
C			RECORD IS INPUT.
C		SDADJ	ADJUSTS SDISTS BASED ON #SDADJ INPUT (EC SDISTS)
C
C	LUMPING CONTROL SPECIFICATIONS (READ IN BY RDLUMP),
C	AND SPECIFICATIONS FOR LUMPED GROUPS.
C
	PROGRAM LUMPGEN
	INCLUDE 'LUMPSPEC.FOR'
C
C
C	LOCAL SPECIFICATIONS
C
	CHARACTER*60 LCCFIL,DFLMOD,VSDFIL,MODFIL,PRMFIL,PHFMOD
	CHARACTER*60 INFILE,OUTFIL
	CHARACTER INLIN*80,SDRUIC*60,CMPUIC*60
C
	LOGICAL ERRIND,INTIN,ADJSD,NOADJ,USECMP,OUTMSG,MPIN
	DATA ADJSD/.FALSE./,NOADJ/.FALSE./,USECMP/.FALSE./
	DATA OUTMSG/.FALSE./
C
C	INITIALIZE LUMPING PARAMETERS
C	INITIALIZE LUMPING AND TEMPERATURE AS BEING UNDEFINED.
C
	LPRE=0
	LPRECH=' '
	NOLPC=.TRUE.
	TEMPR=0.0
C
C	DON'T COMPUTE T-DEPENDENT K'S
C
	THIGH=0.0
	TLOW=THIGH
	THIGH=TLOW
C
C
C	GET AND DECODE COMMAND LINE
C
	CALL GETARG (1,INFILE)
	IF (INFILE(1:1).EQ.' ') GOTO 800
	IF (INFILE(1:4).EQ.'CMP=') THEN
		USECMP=.TRUE.
		INFILE=INFILE(5:)
		OUTMSG=.TRUE.
	ENDIF
C
C	OPEN OUTPUT FILE
C
	CALL GETARG (2,OUTFIL)
	IF (OUTFIL(1:1).EQ.' ') THEN
		WRITE (ICRT,*) 'Output file not specified.'
		GOTO 800
	ENDIF
C
	OPEN (UNIT=4,FILE=OUTFIL,STATUS='UNKNOWN')
C
C	GET PARAMETERS FILE FROM COMMAND LINE
C
	NP=3
	PRMFIL=' '
	LPRMFL=0
    2	CALL GETARG (NP,IOB160)
	IF (IOB160(1:7).EQ.'PREFIX=') THEN
		LPRECH=IOB160(8:)
		LPRE=LNBLNK(LPRECH)
	ELSEIF (IOB160(1:1).EQ.' ') THEN
		GOTO 3
	ELSE
		PRMFIL=IOB160
		LPRMFL=LNBLNK(PRMFIL)
	ENDIF
	NP=NP+1
	GOTO 2
    3	CONTINUE
C
C	IF prmfil.PRM does not exist, then it is the LCC file
C
	IF (LPRMFL.NE.0) THEN
		INQUIRE(FILE=PRMFIL(1:LPRMFL)//'.PRM',EXIST=ERRIND)
		IF (ERRIND) THEN
			LLCCFL=0
			LCCFIL=' '
		ELSE
			LLCCFL=LPRMFL
			LCCFIL=PRMFIL
			LPRMFL=0
			PRMFIL=' '
		ENDIF
	ELSE
		LLCCFL=0
		LCCFIL=' '
	ENDIF
C
	CALL INITIN (3)
	LDFLMD=0
	DFLMOD=' '
	LVSDFL=0
	VSDFIL=' '
	LMODFL=0
	MODFIL=' '
	LPHFMD=0
	PHFMOD=' '
	MECUIC=' '
	PRMCNV=' '
	SDRUIC=' '
	CMPUIC=' '
	INTIN=.FALSE.
C
C	FIND OUT WHICH TYPE OF .LPC FILE THIS PROGRAM IS USING
C	(LUMPINT OR LUMPGEN VERSION)
C
C	GET PARAMETERS FROM MODELING.PRM, THEN PARAMETER FILE
C
	OPEN (UNIT=7,FILE='MODELING.PRM',STATUS='UNKNOWN')
	MPIN=.TRUE.
C
   10	READ (7,1,END=12) INLIN
    1	FORMAT (A)
   11	L=LNBLNK(INLIN)
	IF (L.LE.4) GOTO 10
	IF (INLIN(1:7).EQ.'DFLMOD=') THEN
		LDFLMD=L-7
		IF (L.EQ.7) THEN
			DFLMOD=' '
		ELSE
			DFLMOD=INLIN(8:L)
		ENDIF
	ELSEIF (INLIN(1:4).EQ."LCC=".AND.(LCCFIL(1:1).EQ.' ')) THEN
		LLCCFL=L-4
		LCCFIL=INLIN(5:)
	ELSEIF (INLIN(1:7).EQ.'VARYSD=') THEN
		LVSDFL=L-7
		IF (L.EQ.7) THEN
			VSDFIL=' '
		ELSE
			VSDFIL=INLIN(8:L)
		ENDIF
	ELSEIF (INLIN(1:4).EQ.'MOD=') THEN
		LMODFL=L-4
		IF (L.EQ.4) THEN
			MODFIL=' '
		ELSE
			MODFIL=INLIN(5:L)
		ENDIF
	ELSEIF (INLIN(1:7).EQ.'PHFMOD=') THEN
		LPHFMD=L-7
		IF (L.EQ.7) THEN
			PHFMOD=' '
		ELSE
			PHFMOD=INLIN(8:L)
		ENDIF
	ELSEIF (INLIN(1:5).EQ.'MECH=') THEN
		IF (L.EQ.5) THEN
			MECUIC=' '
		ELSE
			MECUIC=INLIN(6:L)
		ENDIF
	ELSEIF (INLIN(1:4).EQ.'SDR=') THEN
		IF (L.EQ.4) THEN
			SDRUIC=' '
		ELSE
			SDRUIC=INLIN(5:L)
		ENDIF
	ELSEIF (INLIN(1:4).EQ.'CMP=') THEN
		IF (L.EQ.4) THEN
			CMPUIC=' '
		ELSE
			CMPUIC=INLIN(5:L)
		ENDIF
	ELSEIF (INLIN(1:8).EQ.'PRMCONV=') THEN
		IF (L.EQ.8) THEN
			PRMCNV=' '
		ELSE
			PRMCNV=INLIN(9:L)
		ENDIF
	ELSEIF (INLIN(1:2).EQ.'@=') THEN
		CALL ADDPRE (INLIN,L)
	ELSEIF (INLIN(1:6).EQ.'INTIN:'.OR.INLIN(1:6).EQ.'INTIN=') THEN
C	      - "INTIN:"  COPY INPUT WITH BLANK IN COLUMN 1 UNTIL
C		 NOLNBLNK IN COL 1.  COPY TO TMP.IN.  THIS IS INSERTED
C		 RIGHT BEFORE THE FIRST .INT OR .SETDEF LINE.
		OPEN (UNIT=8,FILE='TMP.IN',STATUS='UNKNOWN')
		INTIN=.TRUE.
   14		READ (7,1,END=15) INLIN
		IF (INLIN(1:1).NE.' ') THEN
			CLOSE (UNIT=8)
			GOTO 11
		ELSE
			L=LNBLNK(INLIN)
			IF (L.GE.2) WRITE (8,1) INLIN(2:L)
			GOTO 14
		ENDIF
   15		CLOSE (UNIT=8)
		GOTO 12
	ENDIF
	GOTO 10
C
   12	CLOSE (UNIT=7)
C
	IF (MPIN.AND.(LPRMFL.NE.0)) THEN
		MPIN=.FALSE.
		OPEN (UNIT=7,FILE=PRMFIL(1:LPRMFL)//'.PRM',
     &		 STATUS='OLD')
		GOTO 10
	ENDIF
C
C	PROCESS COMPOSITIONS, IF APPLICABLE
C
	IF (USECMP) THEN
		L=LNBLNK(INFILE)
		IF (CMPUIC(1:1).EQ.' ') THEN
			INFILE(L+1:)='.CMP'
		ELSE
			INFILE=CMPUIC(1:LNBLNK(CMPUIC))//INFILE(1:L)
     &			 //'.CMP'
		ENDIF
	ENDIF
C
C	OPEN INPUT FILE
C
	IOB160=INFILE
	CALL FILEIN
	IF (IORET.EQ.1) GOTO 810
C
	IF (USECMP) THEN
		IOB160='.LUMP'
		L=5
		GOTO 101
	ENDIF
C
C	READ AND COPY RECORDS UNTIL A '.LUMP(G)  ', '.EMIT', '.TEMP',
C	.SETDEF, .INT, OR 'MODEL=' RECORD IS READ.
C	IGNORE ALL RECORDS STARTING WITH ".LUMP" EXCEPT FOR THE ABOVE.
C
  100	CALL INBUF ('NEXT: ',6)
	IF (IORET.EQ.2) THEN
C		(IORET=2 WITH POSITIVE INPUT UNIT MEANS <EOF>.
C		IORET=2 WITH NEGATIVE INPUT UNIT MEANS
C		FAILED TO FIND INCLUDE FILE.)
		IF (IN.LT.0) GOTO 890
		GOTO 200
	ENDIF
	L=LNBLNK(IOB160)
C
  101	IF (IOB160(1:6).EQ.'MODEL=') THEN
		IF (DFLMOD(1:1).EQ.' ') THEN
			LDFLMD=L-6
			IF (LDFLMD.GT.0) THEN
				DFLMOD=IOB160(7:L)
			ELSE
				DFLMOD=' '
				LDFLMD=1
			ENDIF
		ELSE
			WRITE (4,'(''MODEL='',A)') DFLMOD(1:LDFLMD)
		ENDIF
	ELSEIF (IOB160(1:8).EQ.'.LUMPPRE') THEN
		LPRE=MIN0(L,13)
		LPRECH=IOB160(10:LPRE)
		LPRE=LPRE-9
	ELSEIF (IOB160(1:13).EQ.'.LUMP VARYSD=') THEN
		LVSDFL=L-13
		IF (L.EQ.13) THEN
			VSDFIL=' '
		ELSE
			VSDFIL=IOB160(14:L)
		ENDIF
	ELSEIF (IOB160(1:5).EQ.'.TEMP') THEN
		WRITE (4,1) IOB160(1:L)
		IF (NOLPC) THEN
			IOB160(6:6)=' '
			CALL PARSE0 (2,IOB160,80)
			CALL PARSER (2,TEMPR,ERRIND,IOB160)
			IF (ERRIND) GOTO 820
C*		ELSE
C*			WRITE (ICRT,*) '.TEMP INPUT AFTER .LUMP'
C*			GOTO 820
		ENDIF
	ELSEIF (IOB160(1:4).EQ.'.INT'.OR.IOB160(1:7).EQ.'.SETDEF') THEN
		IF (INTIN) THEN
			OPEN (UNIT=8,FILE='TMP.IN',STATUS='OLD')
   18			READ (8,1,END=17) INLIN
			WRITE (4,1) INLIN(1:LNBLNK(INLIN))
			GOTO 18
   17			CLOSE (UNIT=8,STATUS='DELETE')
			INTIN=.FALSE.
		ENDIF
		WRITE (4,1) IOB160(1:L)
	ELSEIF (IOB160(1:7).EQ.'.LUMP  '.OR.
     &	       IOB160(1:7).EQ.'.LUMPG '.OR.
     &	       IOB160(1:11).EQ.'.LUMP TEST '.OR.
     &	       IOB160(1:10).EQ.'.LUMP MIX ') THEN
C
C		CAN ONLY LUMP IF LPC FILE SPECIFED
C
		IF (LCCFIL(1:1).EQ.' ') THEN
			WRITE (ICRT,*) 'LCC FILE MUST BE S',
     &			 'PECIFIED TO PROCESS .LUMP.'
			GOTO 890
		ENDIF
C
C		".LUMP TEST" and ".LUMP MIX" TREATED LIKE .LUMP)
C
C		LUMPING SPECIFIED.  OPEN LUMPING PARAMETER FILE,
C		THEN INITILIZE LUMPED PARMS, IF NOT DONE ALREADY
C
		IF (NOLPC) THEN
			NOLPC=.FALSE.
C			INITIALIZE TEMPERATURE, PREFIX
			IF (TEMPR.EQ.0.0) TEMPR=300.0
			IOB160=LCCFIL(1:LLCCFL)
			IOB160(LLCCFL+1:LLCCFL+4)='.LCC'
			OPEN (UNIT=2,FILE=IOB160,STATUS='OLD',ERR=810)
			CALL RDLUMP (-2,3,3)
			WRITE (4,102) TEMPR
  102			FORMAT ('! Lumping T = ',F8.2)
C
		ENDIF
C
C		DO LUMPING
C
		CALL GENLMP (4)
		IF (IORET.EQ.2) THEN
			IF (IN.LT.0) GOTO 890
			GOTO 200
		ENDIF
C
C		RESET LUMPING PREFIX TO DEFALUT
C
		LPRE=0
		LPRECH=' '
C
	ELSEIF (IOB160(1:8).EQ.'#VARYSD=') THEN
C
C		VARYSD PROCESSING SPECIFIED.  CALL VSDSUB TO DO IT
C		USING DEFAULT (OR ONLY) MODEL, AND OUTPUT RESULTS ON UNIT 4.
C
		LVSD=L-8
		IF (LVSD.LE.0) THEN
			WRITE (ICRT,*) 'BAD #VARYSD= INPUT'
			GOTO 890
		ENDIF
C
		VSDFIL(LVSDFL+1:LVSDFL+LVSD)=IOB160(9:L)
		LVSDFL=LVSDFL+LVSD
		MODFIL(LMODFL+1:LMODFL+LDFLMD)=DFLMOD(1:LDFLMD)
		LMODFL=LMODFL+LDFLMD
		IF (PHFMOD(1:1).EQ.' ') THEN
			PHFMOD=MODFIL
			LPHFMD=LMODFL
		ENDIF
C
		I=4
		CALL VSDSUB (I,LVSDFL,VSDFIL,LPHFMD,PHFMOD)
		IF (I.EQ.0) THEN
			WRITE (ICRT,*) 'VARYSD FAILED'
			GOTO 890
		ENDIF
C
	ELSEIF (IOB160(1:6).EQ.'#SDADJ') THEN
C
		IF (NOADJ) THEN
 1021			CALL INBUF ('BYPASS: ',8)
			IF (IOB160(1:4).NE.'#END') GOTO 1021
C
		ELSE
C
C			ADJUSTS SDIST (READ LATER)
C
			ADJSD=.TRUE.
			CALL SDADJ1(I)
			IF (I.NE.0) GOTO 890
		ENDIF
C
	ELSEIF (ADJSD.AND.IOB160(1:4).EQ.'.SD-') THEN
C
C		PROCESS SDIST IF BEING ADJUSTED
C
		CALL SDADJ (I,IOB160(5:),SDRUIC)
		IF (I.NE.0) GOTO 890
		ADJSD=.FALSE.
C
C
	ELSEIF (IOB160(1:7).EQ.'.USESD-') THEN
C
C		USE FOLLOWING AS SDIST.  IGNORE ANY SUBSEQUENT #SDADJ
C		INPUT
C
		NOADJ=.TRUE.
		ADJSD=.FALSE.
		WRITE (4,1) '.'//IOB160(5:L)

	ELSEIF (IOB160(1:5).EQ.'.DSD-') THEN
C
C		DEFAULT SDIST TO USE IF NO SDADJ INPUT.  TREAT AS
C		"USE RUN" IF SDADJ INPUT"
C
		IF (ADJSD) THEN
			IOB160=' Use Run'
			CALL SDADJ (I,IOB160,SDRUIC)
			IF (I.NE.0) GOTO 890
			ADJSD=.FALSE.
		ELSE
			WRITE (4,1) '.'//IOB160(3:L)
		ENDIF

	ELSEIF (IOB160(1:5).NE.'.LUMP') THEN
C
C		IGNORE UNRECOGNIZED '.LUMP' RECORDS.  (USED FOR
C		OTHER LUMPING PROGRAMS, SUCH AS "LUMPINT.
C		OTHERWISE, SIMPLY PASS LINE
C
		WRITE (4,1) IOB160(1:L)
C
C
	ENDIF
	GOTO 100
C
C	END OF INPUT.  FIGURE WHICH MODEL USED, AND OUTPUT NAME 
C	IN 'STATUS.TMP' FILE.
C
C
  200	CLOSE (UNIT=4)
C
	IF (ADJSD) WRITE (ICRT,*) 'Warning:  #SDADJ input ignored.'
C
C	WRITE MECHANISM NAME IN STATUS.TMP FILE
C
	OPEN (UNIT=3,FILE='STATUS.TMP',STATUS='UNKNOWN')
	WRITE (3,1) DFLMOD(1:LDFLMD)
	CLOSE (UNIT=3)
C
C	DONE
C
	IF (OUTMSG) THEN
		WRITE (6,*) 'File = '//OUTFIL(1:LNBLNK(OUTFIL))
     &		 //' created.'
	ENDIF
C
	CALL EXIT (0)
C
C
C	ERROR EXIT.  DELETE STATUS.TMP FILE.
C
  800	WRITE (ICRT,*) 'Processes modeling input files for '
     &	 //'lumping with fixed-parameter mechanism'
	WRITE (ICRT,*) 'Use: LUMPGEN inputfile outputfile '
     &	 //'[prmfile | LCCfile] [PREFIX=prefix]'
	WRITE (ICRT,*) '     Use CMP=cmpfile for inputfile to '
     &	 //'process composition in CMP= folder'
	GOTO 899
  810	WRITE (ICRT,*) 'CAN''T OPEN ',IOB160(1:LNBLNK(IOB160))
	GOTO 899
  820	WRITE (ICRT,*) 'ERROR DECODING INPUT RECORD:'
	WRITE (ICRT,*) IOB160(1:72)
	GOTO 890
C
C	ERROR EXIT WHEN READING INPUT FILE
C
  890	CLOSE (UNIT=4,STATUS='DELETE')
C
  899	OPEN (UNIT=1,FILE='STATUS.TMP',STATUS='UNKNOWN')
	CLOSE (UNIT=1,STATUS='DELETE')
	CALL EXIT (2)
	END
