C	LUMPINT.FTN
C
C	PROGRAM TO PRE-PROCESS "INT" FILES FOR LUMPING.
C
C	PROGRAM INFO. PASSED THROUGH COMMAND LUNE.  MUST BE
C	INVOKED BY
C
C		RUN LUMPINT/CMD="infile outfile [parmfile] [GN1FIL]"
C	WHERE
C	infile =	INPUT FILE (FULL NAME)
C	outfile =	OUTPUT FILE
C	parmfile =	PARAMETER FILE.  IF NOT INPUT, USES MODELING.PRM
C			(W/O EXTENSTION.)  IF NO .PRM FILE, LOOKS USES
C			.LPC FILE.
C	GN1FIL = 	GN1 file to read parameters for VOC with special
C			product processing.  It is processed using parameter
C			"GX".
C
C	PARAMETERS USED:
C
C	LMPPRM1 OR DFLMOD:	DEFALUT MODEL USED.  
C			MODEL USED FOR VARYSD PROCESSING
C			AND OUTPUT IN MODEL= RECORD REGARDLESS OF LUMPING.
C	LMPPRM2 OR LPC:	USES lpcfile.LPC AS LUMPING CONTROL FILE
C			IF NOT SPECIFIED, THEN LUMPING NOT ALLOWED.
C	LMPPRM3 OR MODPRE:	IF SPECIFIED, LUMPING RESULT DETERMINES
C			MODEL NAME, WITH THIS PRAMETER BEING USED AS MODEL
C			NAME PREFIX.
C			(HOWEVER, IF EMISSIONS PROCESSING SPECIFED,
C			THEN DEFAULT MODEL IS USED.)
C	SARPRM		SAROAD PARAMETER FILE
C	SARTYPE		SAROAD NUMBER TYPE ("ARB", "EPA", ETC.)
C
C	(USED IF VARYSD INPUT ONLY)
C
C	VSD:		VDS UIC
C	MOD:		MODEL UIC
C
C
C	CALLS:
C		RDLUMP	SUBROUTINE TO READ LUMPING CONTROL FILE
C
C		ILMPSB	LUMPING SUBROUTINE FOR COMPOSITION INPUT
C
C		LMPEMI	CONVERTS EMISSIONS DATA AS FROM MASS PER 
C			SAROAD TO MOLES PER DETAILED MODEL SPECIES
C		LMPSUB	CALCULATES LUMPED SPECIES LEVELS AND 
C			PARAMETERS FROM DETAILED MODEL SPECIES
C			COMPOSITIONS (FOR EMISSIONS PROCESSING)
C		VSDSUB	FOR VARYSD PROCESSING, IF A #VARYSD=
C			RECORD IS INPUT.
C		SDADJ	ADJUSTS SDISTS BASED ON #SDADJ INPUT (EC SDISTS)
C
C	LUMPING CONTROL SPECIFICATIONS (READ IN BY RDLUMP),
C	AND SPECIFICATIONS FOR LUMPED GROUPS.
C
	PROGRAM LUMPINT
	INCLUDE 'LUMPSPEC.FOR'
C
C
C	SPECIFICATIONS OF ARRAYS USED FOR DETAILED MODEL SPECIES
C	CALCULATED FOR INPUT EMISSIONS PROFILE.
C
C	MAXNMS	MAX. NO DETAILED MODEL SPECIES
C	NMS	NO. DETAILED MODEL SPECIES IN PROFILE
C	MSNAM	MODEL SPECIES NAME
C	MSLVL	MOLES MODEL SPECIES
C	MSNC	NUMBER OF CARBONS
C	MSMW	MOLECULAR WEIGHT
C
	PARAMETER (MAXNMS=200)
	INTEGER NMS
	CHARACTER*8 MSNAM(MAXNMS)
	REAL*4 MSLVL(MAXNMS),MSNC(MAXNMS),MSMW(MAXNMS)
C
C
C	MAXIMUM TYPE INDICES  (TYPMAX(10) SET IF "ETHE" SPECIES)
C
	INTEGER TYPMAX(10)
	DATA TYPMAX/10*0/
C
C
C	LOCAL SPECIFICATIONS
C
	CHARACTER*4 LPCKOD
	CHARACTER*40 LPCFIL,MODPRE,DFLMOD,VSDFIL,MODFIL,SARFIL,PRMFIL,
     &	 PHFMOD,MIXLPC
	CHARACTER INLIN*80,SDRUIC*40
C
	LOGICAL NOSAR,FXDMOD,ERRIND,TSTKOD,INTIN,ADJSD,NOADJ
	CHARACTER*4 SARKOD
	DATA NOSAR/.TRUE./,ADJSD/.FALSE./,NOADJ/.FALSE./
C
	CHARACTER*60 GN1FIL
	COMMON /GN1INFO/ GN1FIL
C
C
C	INITIALIZE LUMPING PARAMETERS
C	INITIALIZE LUMPING AND TEMPERATURE AS BEING UNDEFINED.
C
	LPRE=0
	LPRECH=' '
	NOLPC=.TRUE.
	TEMPR=0.0
C
C	DON'T COMPUTE T-DEPENDENT K'S
C
	THIGH=0.0
	TLOW=THIGH
	THIGH=TLOW
C
C	** TEST USING T-DEPENDENT K'S
C
	THIGH=330.
	TLOW=270.
C
C	GET AND DECODE COMMAND LINE
C	OPEN INPUT FILE
C
	CALL GETARG (1,IOB160)
	IF (IOB160(1:1).EQ.' ') GOTO 800
	CALL INITIN (3)
	CALL FILEIN
	IF (IORET.EQ.1) GOTO 810
C
C	GET GN1 FILE, IF APPLICABLE AND MAKE SURE IT EXISTS.  FULL
C	EXTENSION EXPECTED.
C
	CALL GETARG (4,GN1FIL)
	LGN1FL=LNBLNK(GN1FIL)
C
C	OPEN OUTPUT FILE
C
	CALL GETARG (2,IOB160)
	IF (IOB160(1:1).EQ.' ') GOTO 800
C
	OPEN (UNIT=4,FILE=IOB160,STATUS='UNKNOWN')
C
C	GET PARAMETERS FILE FROM COMMAND LINE
C
	CALL GETARG (3,PRMFIL)
	IF (PRMFIL(1:1).EQ.' ') THEN
		IOB160='MODELING.PRM'
		L=13
	ELSE
		L=LNBLNK(PRMFIL)
		IOB160=PRMFIL(1:L)//'.PRM'
		L=L+4
	ENDIF
C
C	FIND OUT WHICH TYPE OF .LPC FILE THIS PROGRAM IS USING
C	(LUMPINT OR LUMPGEN VERSION)
C
	CALL LPCTYP (LPCKOD)
	LPCKOD(4:4)='='
C
C	GET PARAMETERS FROM PARAMETER FILE (OR MODELING.PRM)
C
	OPEN (UNIT=7,FILE=IOB160,STATUS='OLD',ERR=1010) ! READONLY
	LLPCFL=0
	LPCFIL=' '
	GOTO 1011
C
C	IF prmfil.PRM does not exist, use name for .LPC file
C
 1010	LPCFIL=PRMFIL
	LLPCFL=L-4
	OPEN (UNIT=7,FILE='MODELING.PRM',STATUS='UNKNOWN')
C
 1011	CONTINUE
	LDFLMD=0
	DFLMOD=' '
	LMODPR=0
	MODPRE=' '
	LVSDFL=0
	VSDFIL=' '
	LMODFL=0
	MODFIL=' '
	LPHFMD=0
	PHFMOD=' '
	SARKOD='    '
	SARFIL=' '
	LSARFL=0
	MECUIC=' '
	PRMCNV=' '
	SDRUIC=' '
	INTIN=.FALSE.
	MIXLPC=' '
C
   10	READ (7,1,END=12) INLIN
    1	FORMAT (A)
   11	L=LNBLNK(INLIN)
	IF (L.LE.4) GOTO 10
	IF (INLIN(1:7).EQ.'DFLMOD=') THEN
		LDFLMD=L-7
		IF (L.EQ.7) THEN
			DFLMOD=' '
		ELSE
			DFLMOD=INLIN(8:L)
		ENDIF
	ELSEIF (INLIN(1:4).EQ.LPCKOD.AND.(LPCFIL(1:1).EQ.' '.OR.
     &	 LPCFIL.NE.PRMFIL)) THEN
		LLPCFL=L-4
		LPCFIL=INLIN(5:L)
	ELSEIF (INLIN(1:7).EQ.'MIXLPC=') THEN
		LMIXLC=L-7
		MIXLPC=INLIN(8:L)
	ELSEIF (INLIN(1:4).EQ.'MPR=') THEN
		LMODPR=L-4
		IF (L.EQ.4) THEN
			MODPRE=' '
		ELSE
			MODPRE=INLIN(5:L)
		ENDIF
	ELSEIF (INLIN(1:7).EQ.'MODPRE=') THEN
		LMODPR=L-7
		IF (L.EQ.7) THEN
			MODPRE=' '
		ELSE
			MODPRE=INLIN(8:L)
		ENDIF
	ELSEIF (INLIN(1:7).EQ.'VARYSD=') THEN
		LVSDFL=L-7
		IF (L.EQ.7) THEN
			VSDFIL=' '
		ELSE
			VSDFIL=INLIN(8:L)
		ENDIF
	ELSEIF (INLIN(1:4).EQ.'MOD=') THEN
		LMODFL=L-4
		IF (L.EQ.4) THEN
			MODFIL=' '
		ELSE
			MODFIL=INLIN(5:L)
		ENDIF
	ELSEIF (INLIN(1:7).EQ.'PHFMOD=') THEN
		LPHFMD=L-7
		IF (L.EQ.7) THEN
			PHFMOD=' '
		ELSE
			PHFMOD=INLIN(8:L)
		ENDIF
	ELSEIF (INLIN(1:5).EQ.'MECH=') THEN
		IF (L.EQ.5) THEN
			MECUIC=' '
		ELSE
			MECUIC=INLIN(6:L)
		ENDIF
	ELSEIF (INLIN(1:4).EQ.'SDR=') THEN
		IF (L.EQ.4) THEN
			SDRUIC=' '
		ELSE
			SDRUIC=INLIN(5:L)
		ENDIF
	ELSEIF (INLIN(1:8).EQ.'PRMCONV=') THEN
		IF (L.EQ.8) THEN
			PRMCNV=' '
		ELSE
			PRMCNV=INLIN(9:L)
		ENDIF
	ELSEIF (INLIN(1:2).EQ.'@=') THEN
		CALL ADDPRE (INLIN,L)
	ELSEIF (INLIN(1:4).EQ.'SARTYPE=') THEN
		READ (INLIN,'(8X,A4)') SARKOD
	ELSEIF (INLIN(1:4).EQ.'GN1='.AND.GN1FIL(1:1).NE.' ') THEN
		GN1FIL=INLIN(5:LNBLNK(INLIN))//GN1FIL
	ELSEIF (INLIN(1:7).EQ.'SARPRM=') THEN
		LSARFL=L-7
		IF (L.GT.7) THEN
			SARFIL=INLIN(8:L)
		ELSE
			SARFIL=' '
		ENDIF
	ELSEIF (INLIN(1:6).EQ.'INTIN:'.OR.INLIN(1:6).EQ.'INTIN=') THEN
C	      - "INTIN:"  COPY INPUT WITH BLANK IN COLUMN 1 UNTIL
C		 NOLNBLNK IN COL 1.  COPY TO TMP.IN.  THIS IS INSERTED
C		 RIGHT BEFORE THE FIRST .INT OR .SETDEF LINE.
		OPEN (UNIT=8,FILE='TMP.IN',STATUS='UNKNOWN')
		INTIN=.TRUE.
   14		READ (7,1,END=15) INLIN
		IF (INLIN(1:1).NE.' ') THEN
			CLOSE (UNIT=8)
			GOTO 11
		ELSE
			L=LNBLNK(INLIN)
			IF (L.GE.2) WRITE (8,1) INLIN(2:L)
			GOTO 14
		ENDIF
   15		CLOSE (UNIT=8)
		GOTO 12
	ENDIF
	GOTO 10
C
   12	CLOSE (UNIT=7)
C
	IF (SARFIL(1:1).EQ.' ') THEN
		SARFIL='SAROAD.PRM'
		LSARFL=10
	ENDIF
	FXDMOD=MODPRE(1:1).EQ.' '
C
	IF (GN1FIL(1:1).NE.' ') THEN
		INQUIRE (FILE=GN1FIL,EXIST=ERRIND)
		IF (.NOT.ERRIND) THEN
			WRITE (ICRT,*) 'GN1 File = '//
     &		 		GN1FIL(1:LNBLNK(GN1FIL))//
     &				' does not exist'
			GOTO 890
		ENDIF
	ENDIF
C
C	READ AND COPY RECORDS UNTIL A '.LUMP  ', '.EMIT', '.TEMP',
C	.SETDEF, .INT, OR 'MODEL=' RECORD IS READ.
C	IGNORE ALL RECORDS STARTING WITH ".LUMP" EXCEPT FOR THE ABOVE.
C
  100	CALL INBUF ('NEXT: ',6)
	IF (IORET.EQ.2) THEN
C		(IORET=2 WITH POSITIVE INPUT UNIT MEANS <EOF>.
C		IORET=2 WITH NEGATIVE INPUT UNIT MEANS
C		FAILED TO FIND INCLUDE FILE.)
		IF (IN.LT.0) GOTO 890
		GOTO 200
	ENDIF
C-P
C.	L=LENSTR(IOB160,80)
C-I
	L=LNBLNK(IOB160)
C-
	IF (IOB160(1:6).EQ.'MODEL=') THEN
		IF (DFLMOD(1:1).EQ.' ') THEN
			LDFLMD=L-6
			IF (LDFLMD.GT.0) THEN
				DFLMOD=IOB160(7:L)
			ELSE
				DFLMOD=' '
				LDFLMD=1
			ENDIF
		ELSE
			WRITE (4,'(''MODEL='',A)') DFLMOD(1:LDFLMD)
		ENDIF
	ELSEIF (IOB160(1:8).EQ.'.LUMPPRE') THEN
		LPRE=MIN0(L,13)
		LPRECH=IOB160(10:LPRE)
		LPRE=LPRE-9
	ELSEIF (IOB160(1:13).EQ.'.LUMP VARYSD=') THEN
		LVSDFL=L-13
		IF (L.EQ.13) THEN
			VSDFIL=' '
		ELSE
			VSDFIL=IOB160(14:L)
		ENDIF
	ELSEIF (IOB160(1:5).EQ.'.TEMP') THEN
		WRITE (4,1) IOB160(1:L)
		IF (NOLPC) THEN
			IOB160(6:6)=' '
			CALL PARSE0 (2,IOB160,80)
			CALL PARSER (2,TEMPR,ERRIND,IOB160)
			IF (ERRIND) GOTO 820
C*		ELSE
C*			WRITE (ICRT,*) '.TEMP INPUT AFTER .LUMP'
C*			GOTO 820
		ENDIF
	ELSEIF (IOB160(1:4).EQ.'.INT'.OR.IOB160(1:7).EQ.'.SETDEF') THEN
		IF (INTIN) THEN
			OPEN (UNIT=8,FILE='TMP.IN',STATUS='OLD')
   18			READ (8,1,END=17) INLIN
			WRITE (4,1) INLIN(1:LNBLNK(INLIN))
			GOTO 18
   17			CLOSE (UNIT=8,STATUS='DELETE')
			INTIN=.FALSE.
		ENDIF
		WRITE (4,1) IOB160(1:L)
	ELSEIF (IOB160(1:7).EQ.'.LUMPG ') THEN
C		.LUMPG IS IGNORED BY LUMPINT.  ONLY USED FOR LUMPGEN
C		(IT IS USED FOR SPECIES THAT SHOULD BE EXPLICIT IN DETAILED
C		 MECHANISMS, BUT MAY BE LUMPED FOR CONDENSED OR FIXED PARM
C		 MECHANISMS)
C		COPY LINES UNTIL A "." IS READ (EOF IS NOT PERMITTED)
 1022		CALL INBUF ('NEXT LUMPG: ',11)
		IF (IOB160(1:1).NE.'.') THEN
			WRITE (4,1) IOB160(1:LNBLNK(IOB160))
			GOTO 1022
		ENDIF
C
	ELSEIF (IOB160(1:7).EQ.'.LUMP  '.OR.
     &	       IOB160(1:11).EQ.'.LUMP TEST '.OR.
     &	       IOB160(1:10).EQ.'.LUMP MIX ') THEN
C
C		CAN ONLY LUMP IF LPC FILE SPECIFED
C
		IF (LPCFIL(1:1).EQ.' ') THEN
			WRITE (ICRT,*) LPCKOD(1:3),' FILE MUST BE S',
     &			 'PECIFIED TO PROCESS .LUMP.'
			GOTO 890
		ENDIF
C
C		".LUMP TEST" ... LUMPS TEST MIX, SETS TSTKOD=.TRUE.
C		".LUMP MIX" ... USE MIXLPC= .LPC FILE, IF SPECIFIED.
C
		IF (IOB160(7:10).EQ.'MIX ') THEN
			TSTKOD=.FALSE.
			IF (MIXLPC(1:1).NE.' ') THEN
				LLPCFL=LMIXLC
				LPCFIL=MIXLPC
			ENDIF
		ELSEIF (IOB160(7:11).EQ.'TEST ') THEN
			TSTKOD=.TRUE.
		ELSE
			TSTKOD=.FALSE.
		ENDIF
C
C		LUMPING SPECIFIED.  OPEN LUMPING PARAMETER FILE,
C		THEN INITILIZE LUMPED PARMS, IF NOT DONE ALREADY
C
		IF (NOLPC) THEN
			NOLPC=.FALSE.
C			INITIALIZE TEMPERATURE, PREFIX
			IF (TEMPR.EQ.0.0) TEMPR=300.0
			IOB160=LPCFIL(1:LLPCFL)
			IOB160(LLPCFL+1:LLPCFL+4)='.'//LPCKOD(1:3)
			OPEN (UNIT=2,FILE=IOB160,STATUS='OLD',ERR=810)
C							! READONLY
			CALL RDLUMP (-2,3,3)
			WRITE (4,102) TEMPR
  102			FORMAT ('! Lumping T = ',F8.2)
C
		ENDIF
C
C		DO LUMPING
C
		CALL ILMPSB (4,TYPMAX,FXDMOD,TSTKOD)
		IF (IORET.EQ.2) THEN
			IF (IN.LT.0) GOTO 890
			GOTO 200
		ENDIF
C
C		RESET LUMPING PREFIX TO DEFALUT
C
		LPRE=0
		LPRECH=' '
C
	ELSEIF (IOB160(1:6).EQ.'.EMIT ') THEN
C
C		EMISSIONS LUMPING SPECIFIED.
C
		IF (NOLPC) THEN
			NOLPC=.FALSE.
C			INITIALIZE TEMPERATURE, PREFIX
			IF (TEMPR.EQ.0.0) TEMPR=300.0
			IOB160=LPCFIL(1:LLPCFL)
			IOB160(LLPCFL+1:LLPCFL+4)='.'//LPCKOD(1:3)
C-P
C.			OPEN (UNIT=2,FILE=IOB160,STATUS='OLD',ERR=810,
C.     &			 READONLY)
C-I
			OPEN (UNIT=2,FILE=IOB160,STATUS='OLD',ERR=810)
C							! READONLY
C-
			CALL RDLUMP (-2,3,2)
			WRITE (4,102) TEMPR
C
		ENDIF
C
C		LOAD DETAILED MODEL SPECIES SAROAD ASSIGNMENTS INTO MEMORY
C
		IF (NOSAR) THEN
			OPEN (UNIT=3,FILE=SARFIL(1:LSARFL),
     &			 STATUS='OLD',ERR=830)	! READONLY
			CALL LDSAR (3,SARKOD,ERRIND)
			IF (ERRIND) GOTO 890
			NOSAR=.FALSE.
		ENDIF
C
C		CALL LMPEMI TO READ EMISSIONS DATA AND CONVERT IT TO
C		MOLES MODEL SPECIES.
C
		CALL LMPEMI (4,0,MAXNMS,NMS,MSNAM,MSLVL,MSNC,MSMW,1,
     &		 TOTMOL,TOTC,TOTWT,UNKWT)
		IF (IORET.EQ.2) THEN
			IF (IN.LT.0) GOTO 890
		ENDIF
		IF (NMS.EQ.0) GOTO 100
C
C		CALL LMPSUB TO CONVERT EMISSIONS DATA FROM WEIGHT PER SAROAD
C		TO MOLES PER DETAILED MODEL SPECIES
C
		INTFMT=.TRUE.
		CALL LMPSUB (4,4,NMS,MSNAM,MSLVL,MSNC,MSMW)
		IF (IORET.EQ.2) GOTO 200
C
C		RESET LUMPING PREFIX TO DEFALUT
C
		LPRE=0
		LPRECH=' '
C
	ELSEIF (IOB160(1:8).EQ.'#VARYSD=') THEN
C
C		VARYSD PROCESSING SPECIFIED.  CALL VSDSUB TO DO IT
C		USING DEFAULT (OR ONLY) MODEL, AND OUTPUT RESULTS ON UNIT 4.
C
		LVSD=L-8
		IF (LVSD.LE.0) THEN
			WRITE (ICRT,*) 'BAD #VARYSD= INPUT'
			GOTO 890
		ENDIF
C
		VSDFIL(LVSDFL+1:LVSDFL+LVSD)=IOB160(9:L)
		LVSDFL=LVSDFL+LVSD
		MODFIL(LMODFL+1:LMODFL+LDFLMD)=DFLMOD(1:LDFLMD)
		LMODFL=LMODFL+LDFLMD
		IF (PHFMOD(1:1).EQ.' ') THEN
			PHFMOD=MODFIL
			LPHFMD=LMODFL
		ENDIF
C
		I=4
		CALL VSDSUB (I,LVSDFL,VSDFIL,LPHFMD,PHFMOD)
		IF (I.EQ.0) THEN
			WRITE (ICRT,*) 'VARYSD FAILED'
			GOTO 890
		ENDIF
C
	ELSEIF (IOB160(1:9).EQ.'.LUMP LPC') THEN
C
C		READS IN LPC FILE NAME (OVERRIDES ONE IN PARM
C		FILE)
C
		IF (L.LT.11) THEN
			WRITE (ICRT,*) 'BAD .LUMP LPC INPUT'
			GOTO 890
		ENDIF
		NOLPC=.TRUE.
		LLPCFL=L-10
		LPCFIL=IOB160(11:L)
C
	ELSEIF (IOB160(1:6).EQ.'#SDADJ') THEN
C
		IF (NOADJ) THEN
 1021			CALL INBUF ('BYPASS: ',8)
			IF (IOB160(1:4).NE.'#END') GOTO 1021
C
		ELSE
C
C			ADJUSTS SDIST (READ LATER)
C
			ADJSD=.TRUE.
			CALL SDADJ1(I)
			IF (I.NE.0) GOTO 890
		ENDIF
C
	ELSEIF (ADJSD.AND.IOB160(1:4).EQ.'.SD-') THEN
C
C		PROCESS SDIST IF BEING ADJUSTED
C
		CALL SDADJ (I,IOB160(5:),SDRUIC)
		IF (I.NE.0) GOTO 890
		ADJSD=.FALSE.
C
C
	ELSEIF (IOB160(1:7).EQ.'.USESD-') THEN
C
C		USE FOLLOWING AS SDIST.  IGNORE ANY SUBSEQUENT #SDADJ
C		INPUT
C
		NOADJ=.TRUE.
		ADJSD=.FALSE.
		WRITE (4,1) '.'//IOB160(5:L)

	ELSEIF (IOB160(1:5).EQ.'.DSD-') THEN
C
C		DEFAULT SDIST TO USE IF NO SDADJ INPUT.  TREAT AS
C		"USE RUN" IF SDADJ INPUT"
C
		IF (ADJSD) THEN
			IOB160=' Use Run'
			CALL SDADJ (I,IOB160,SDRUIC)
			IF (I.NE.0) GOTO 890
			ADJSD=.FALSE.
		ELSE
			WRITE (4,1) '.'//IOB160(3:L)
		ENDIF

	ELSEIF (IOB160(1:5).NE.'.LUMP') THEN
C
C		IGNORE UNRECOGNIZED '.LUMP' RECORDS.  (USED FOR
C		OTHER LUMPING PROGRAMS, SUCH AS "LUMPRADM".
C		OTHERWISE, SIMPLY PASS LINE
C
		WRITE (4,1) IOB160(1:L)
C
C
	ENDIF
	GOTO 100
C
C	END OF INPUT.  FIGURE WHICH MODEL USED, AND OUTPUT NAME 
C	IN 'STATUS.TMP' FILE.
C
C
  200	CLOSE (UNIT=4)
C
	IF (ADJSD) WRITE (ICRT,*) 'Warning:  #SDADJ input ignored.'
C
	OPEN (UNIT=3,FILE='STATUS.TMP',STATUS='UNKNOWN')
C
	IF (FXDMOD.OR.(.NOT.NOSAR)) THEN
C
C		USE DEFAULT MODEL IF NO MODPRE SPECIFIED,
C		OR IF EMISSIONS PROCESSING DONE
C
		WRITE (3,1) DFLMOD(1:LDFLMD)
C
	ELSEIF (NOLPC) THEN
C
C		IF NO LUMPING DONE AND A MODEL PREFIX SPECIFIED,
C		USE PREFIX ALONE.  (NOTE THAT FXTMOD=F MEANS MODPRE
C		IS DEFINED.)
C
		WRITE (3,1) MODPRE(1:LMODPR)
C
	ELSE
C
C		FIGURE MODEL NAME BASED ON RESULTS OF LUMPING
C
		L=LMODPR
		INLIN=MODPRE(1:LMODPR)
C
C		ADD "E" SUFFIX TO MODEL NAME IF TYPMAX(10) SET TO NONZERO
C
		IF (TYPMAX(10).NE.0) THEN
			L=L+1
			INLIN(L:L)='E'
		ENDIF
C
C		OUTPUT MODEL NAME + MAX GROUP NO'S
C
		NTYP=0
		DO 202 I=1,9
		IF (TYPMAX(I).GT.0) NTYP=I
  202		CONTINUE
		IF (NTYP.EQ.0) THEN
			WRITE (3,1) INLIN(1:L)
		ELSE
			WRITE (3,'(A,9I1)') INLIN(1:L),(TYPMAX(I),I=1,NTYP)
		ENDIF
	ENDIF
C
C	DONE
C
	CLOSE (UNIT=3)
	CALL EXIT (0)
C
C
C	ERROR EXIT.  DELETE STATUS.TMP FILE.
C
  800	WRITE (ICRT,*) 'BAD COMMAND LINE'
	GOTO 899
  810	WRITE (ICRT,*) 'CAN''T OPEN ',IOB160(1:LNBLNK(IOB160))
	GOTO 899
  820	WRITE (ICRT,*) 'ERROR DECODING INPUT RECORD:'
	WRITE (ICRT,*) IOB160(1:72)
	GOTO 890
  830	WRITE (ICRT,*) 'SAROAD File = ',SARFIL(1:LSARFL),
     &	 ' does not exist.'
C
C	ERROR EXIT WHEN READING INPUT FILE
C
  890	CLOSE (UNIT=4,STATUS='DELETE')
C
  899	OPEN (UNIT=1,FILE='STATUS.TMP',STATUS='UNKNOWN')
	CLOSE (UNIT=1,STATUS='DELETE')
	CALL EXIT (2)
	END
