      SUBROUTINE RDRXN
C
C  PURPOSE:  READ IN REACTIONS AND RATE CONSTANTS, DETERMINE WHICH SPECIES
C     GO WITH WHAT REACTIONS.  ORDER SPECIES.
C
C  FOR REACTION I:  NRTOSR(I)=      NO. OF REACTANTS (LE 3) FOR RXN# I
C                   IRTOSR(1,I) =   SPECIES NO. OF FIRST REACTANT FOR RXN# I
C                   NPRODS(I) =     STARTING INDEX NO. IN IPRODS FOR RXN# I
C		    NPRODS(I+1)-1 = ENDING INDEX NO. IN IPRODS FOR RXN# I
C		    IPRODS(NPRODS(I)+N-1)= SPECIES NO OF NTH PRODUCT FOR RXN# I
C                   RXTYP(I) = REACTION TYPE:
C		    LKBUF(I) = BUFFER LOC OR REF RXN NO (SEE BELOW)
C		    KPBUF(LKBUF(I)) = FIRST OF THE KINETIC PARMS FOR RXN
C
C  INPUT   TYPE	BUFSIZE	BUFDATA		LKBUF	DESC
C  ------  ----	----	----		-----	----------------
C  SAMEK     0	  0			RXN NO.	SAME K AS REF'D RXN
C  CASEOF    1	  0			RXN NO.	K = RATE OF REF'D RXN
C  -UNUSED-  2
C  CONST     3	  1*	  K		BUFLOC*	CONSTANT K  *(CONSTANT
C						 K'S STORED AT END OF KPBUF)
C  n1,n2,n3  4	  3	  A,EA,B	BUFLOC	STANDARD T. DEP
C  FALLOFF   5	  8	  A0,E0,B0,	BUFLOC	FALLOFF T DEP
C			  AI,EI,BI,F,N
C  LTEMP n   6	  n	   n*T1		IBUFLOC	LINEAR COMBO OF OTHER K'S
C						DEPENDING ON T.
C						IKPBUF: IBUFLOC+0: BUFLOC
C							       +1:   n
C							       +2: RXN NO.
C							     +n+1: RXN NO.
C  PF, PHOT  7	  0	  		PHOTNO.	PHOT K
C  COEF      8      0			COEFNO	K=COEFFICIENT.
C  K1+K2[M]  9      6    A1,EA1,B1  BUFLOC	SPECIAL PRESSURE DEPENDENCE
C                        A2,EA2,B2
C  K0+K3M/(1+K3M/K2)
C           10      9    A0,EA0,B0  BUFLOC	SPECIAL T,P DEPENDENCE
C                        A2,EA2,B2
C                        A3,EA3,B3
C
C                   NRXN = NO OF REACTIONS (DEFINED BY PROGRAM)
C
C    REACTIONS INPUT CONSISTS OF CHARACTER STRING CONSISTING OF THE
C    NONBLANK CHARACTERS OF THE REACTANTS NAMES SEPARATED BY ' + '
C    THEN FOLLOWED BY ' = ' AND THEN PRODUCTS NAMES SEPARATED BY ' + '
C           E.G.         NO2 + HV = NO + O.
C
C  MODIFICATIONS SINCE 6/21/17
C    - Allow automatic renumbering for reactions with blank or 'R' label.
C
	INCLUDE 'PSPECS.FOR'
C
	REAL*8 LITTLE
	PARAMETER (MXCOND=30,MXDEFD=30,LITTLE=1.0E-30)
	LOGICAL BLANKC,DUMRXN,KEQ,NEWTVC,RXOPN,PPM,NEWRXN,EADEGK,
     &   KNOTA,ERRIND
	INTEGER NDEFD,NCOND
	CHARACTER*8 LBCOND(MXCOND),LBDEFD(MXDEFD),GNAME
	CHARACTER*4 VCOCMD(3),LBL,LBL2
	CHARACTER RKBUF*80,TMPRXN*160
	CHARACTER*1 RKBF1(80)
	EQUIVALENCE (RKBUF,RKBF1(1))
C
C	THE FOLLOWING IS NEEDED WHEN KINETIC PARMS IN CM MOLEC UNITS
C	CAN HAVE GREATER OR LOWER MAGNITUDE THAN ALLOWED FOR REAL*4
C
	REAL*8 KPRMIN(9),FAC
C
	DATA VCOCMD /'.#C1','.#D1','.#PS'/
	DATA MAXRLB /1000/
C
	PPM=.FALSE.
	EADEGK=.FALSE.
	KNOTA=.FALSE.
	NEWRXN=.TRUE.
	IF (NOPRP) THEN
		RXOPN=.TRUE.
		VCODFD=.TRUE.
	ELSE
		RXOPN=.FALSE.
		VCODFD=.FALSE.
	ENDIF
	DO 5 I=1,7
    5	VCOCAL(I)=.FALSE.
	IND=4
	NS=0
	INDM=0
	COEFNM(1)='DILUTION'
	COEF(1)=0.0
	INDDIL=1
	COEFNM(2)='LITTLE  '
	COEF(2)=LITTLE
	INDLIL=2
	COEFNM(3)='TEMPR   '
	COEF(3)=TEMPR
	INDTPR=3
	IF (VARYHV) THEN
		COEFNM(4)='HV      '
		COEF(4)=1.0
		INDHV=4
		IF (AIRSHD) THEN
			COEFNM(5)='HEIGHT  '
			COEFNM(6)='EMIT.FAC'
			COEFNM(7)='(E.RATE)'
			COEF(5)=1.0
			COEF(6)=0.082056*TEMPR
C                       EMIT.FAC IS FACTOR TO CONVERT CONCENTRATION UNITS USED
C                       BY EMMISIONS, (USUALLY MILLIMOLES/(METER**3)), TO UNITS
C                       USED IN THE INTEGRATION, (USUALLY PPM).
                        COEF(7)=0.0
			NCOEFV=7
			INDHT=5
			INDEF=6
			INDER=7
		ELSE
			NCOEFV=4
			INDHT=0
			INDEF=0
			INDER=0
		ENDIF
	ELSE
		NCOEFV=3
		INDHT=0
		INDEF=0
		INDER=0
		INDHV=0
	ENDIF
C
	INDDF=0
C
	NRXN=0
        NVTEMP=0
        NVTCO=0
        NGRPS=0		! NO. OF SPECIES GROUPS
	LOCKBF=0	! KINETIC PARMS FOR T-DEP RXNS STORED IN KPBUF
C			! STARTING FROM 1
	LOCIBF=0	! KINETIC PARMS INDICES BUFFER (IKPBUF) COUNTER
	KBFEND=MAXKBF	! CONSTANT K'S STORED IN KPBUF STARTING AT END
	NSGRP=0		! SPECIES GROUPS
	NSGB=0		! BUFFER FOR SPECIES GROUPS
	NCOC2=NCOC1-1
C
	TRCONV=1.0	! CONVERSION FACTOR FOR USE WHEN TREF (INPUT K'S)
C			! NOT SAME AS TREF USED.
	NSUM=0		! NUMBER OF SUM CONC COEFFICIENTS (SUMCOE,SUMSPE)
C
	GOTO 1
C
C      MAIN COMMAND SECTION (NOTE THAT WHEN RDRXN CALLED, IOB160 ALREADY
C       HAS THE FIRST COMMAND).  INPUT WITHOUT '.' IN COL. 1 IGNORED
C
C      'COMMAND' INPUT CONSISTS OF LINES WITH '.' IN COL. 1.
C
C      COMMAND INPUT PROCESSING:
C
C      ..text          -INPUT IGNORED UNTIL NEXT LINE WITH "."
C      .  (ALONE)      -DELINIATES SECTIONS  (SEE BELOW).  ALL NON-COMMAND
c                       INPUT FOLLOWING IT UNTIL NEXT COMMAND IGNORED
C      . label         -DEFINES CONDITION = label AS TRUE (SEE BELOW)
C      . IF label      -FOLLOWING INPUT IGNORED UNTIL A BLANK COMMAND
C                       INPUT IS READ UNLESS CONDITION = label HAS BEEN
C                       DEFINED AS TRUE.  THIS INCLUDES NON-BLANK COMMAND
C                       INPUT.
C      . FOR label     -FOLLOWING INPUT IGNORED UNTIL A BLANK COMMAND
C                       INPUT IS READ IF A PREVIOUS 'FOR' COMMAND CARD
C                       WITH THE SAME LABEL = label HAS BEEN PROCESSED
C      .cmd            -FOLLOWING NON-COMMAND INPUT (E.G. REACTIONS,
C                       SPECIES DEFS, ETC) PROCESSED ACCORDING TO WHAT
C                       COMMAND cmd IS UNTIL ANOTHER COMMAND INPUT
C                       IS INPUT.  SEE CODE BELOW FOR LEGAL COMMANDS.
C      .cmd IF label   -FOLLOWING INPUT IGNORED UNTIL ANOTHER COMMAND
C                       IS INPUT UNLESS CONDITION = label HAS BEEN
C                       DEFINED AS TRUE.
C      .cmd FOR label  -FOLLOWING INPUT IGNORED UNTIL ANOTHER COMMAND
C                       IS INPUT IF A PREVIOUS 'FOR' COMMAND CARD
C                       WITH SAME LABEL HAS BEEN PROCESSED.
C
  100	CALL INBUF ('RDRXN  :',8)
	IF (IORET.EQ.2) GOTO 1999
	IF (IOLEN.EQ.0) GOTO 100
	IF (IOB160(1:1).NE.'.') GOTO 100
C
    1	IF (IOB160(2:2).EQ.'.') GOTO 100
C
	IF (IOB160(1:8).EQ.'.RENAME ') THEN
		CALL PARSE0 (3,IOB160,80)
		CALL PARSE1 (2,IOBF16,I,16,IOB160)
		IF (IOBF16(1:1).EQ.' ') GOTO 1802
		DO 1801 I=1,NS
		IF (NAME(I).EQ.IOBF16) THEN
			CALL PARSE1 (3,IOBF16,IX,16,IOB160)
			IF (IOBF16(1:1).EQ.' ') GOTO 1802
			WRITE (OUT,*) ' ',NAME(I),
     &			 ' renamed to ',IOBF16
			NAME(I)=IOBF16
			GOTO 100
		ENDIF
 1801		CONTINUE
 1802		WRITE (OUT,*) ' ERROR.  BAD .RENAME :',IOB160(1:40)
		NERR=NERR+1
		GOTO 100
C
	ELSEIF (IOB160(1:5).EQ.'.SUM ') THEN
		CALL PARSE0 (3,IOB160,80)
		CALL PARSE1 (2,GNAME,I,8,IOB160)
		IF (NSUM.GT.0) THEN
		  DO 1073 I=1,NSUM
		    IF (SUMCOE(I).EQ.GNAME) THEN
		      I1=NSUMSP(I)+1
		      IF (I1.GT.MAXSMS) STOP 'INCREASE MAXSMS'
		      NSUMSP(I)=I1
		      CALL PARSE1 (3,GNAME,J,8,IOB160)
		      SUMSPE(I,I1)=GNAME
C		      WRITE (OUT,*) 'Sum+ ',I,' ',SUMCOE(I),' ',GNAME
		      GOTO 100
		    ENDIF
 1073		  CONTINUE
		ENDIF
		IF (NSUM.EQ.MAXSUM) STOP 'INCREASE MAXSUM'
		NSUM=NSUM+1
		SUMCOE(NSUM)=GNAME
		CALL PARSE1 (3,GNAME,J,8,IOB160)
		SUMSPE(NSUM,1)=GNAME
		NSUMSP(NSUM)=1
C		WRITE (OUT,*) 'Sum  ',NSUM,' ',SUMCOE(NSUM),' ',GNAME
		GOTO 100
	ENDIF
C
	CALL ALIN8(3,IOB160)
	IF (IOB160(1:8).EQ.'  .UNITS') GOTO 150
	IF (IOB160(1:8).EQ.'   .PHOT') GOTO 1500
	IF (IOB160(1:8).EQ.'  .VTEMP') GOTO 1600
	IF (IOB160(1:8).EQ.'  .GROUP') GOTO 1800
	IF (IOB160(1:8).EQ.'    .INS') GOTO 300
	IF (IOB160(1:8).EQ.' .SGROUP') GOTO 1900
C
	IF (IOB160(1:8).EQ.'   .TREF') THEN
		READ (IOB160,'(8X,F8.0)',ERR=1020) TRCONV
		IF (TRCONV.LE.0.0) GOTO 1020
		TRCONV=TREF/TRCONV
		GOTO 100
 1020		WRITE (OUT,*) ' ERROR decoding: ',IOB160(1:16)
		WRITE (ICRT,*) 'Error decoding .TREF input'
		NERR=NERR+1
		TRCONV=1.0
		GOTO 100
	ENDIF
C
	BLANKC=IOB160(7:8).EQ.' .'.OR.IOB160(6:8).EQ.' ..'
	IF (IOB160(9:16).NE.'        ') GOTO 110
	IF (BLANKC) GOTO 100
	GOTO 180
  110  IF (IOB160(9:16).EQ.'      IF') GOTO 120
       IF (IOB160(9:16).EQ.'     FOR') GOTO 130
       IF (BLANKC) GOTO 140
       WRITE (OUT,111) IOB160(9:16),IOB160(5:8)
  111  FORMAT (' UNRECOGNIZED COMMAND QUALIFIER = ''',A8,
     &  '''.  COMMAND = ''',A4,''' PROCESSED ANYWAY.')
       WRITE (ICRT,113) IOB160(1:48)
  113  FORMAT (' UNRECOGNIZED COMMAND QUALIFIER.',
     &  '  COMMAND PROCESSED ANYWAY.'/' DECODED LINE =  ''',
     &  A48,'''')
       NERR=NERR+1
       GOTO 180
C
C      'IF' PROCESSING.  SEE IF LABEL MATCHES LIST IN LBCOND
C
  120  IF (NCOND.EQ.0) GOTO 123
       DO 122 I=1,NCOND
       IF (LBCOND(I).EQ.IOB160(17:24)) GOTO 125
  122  CONTINUE
C  -     DOESN'T MATCH
  123  IF (BLANKC) GOTO 170
       GOTO 100
  125  IF (BLANKC) GOTO 100
       GOTO 180
C
C      'FOR' PROCESSING.
C
  130  IF (NDEFD.EQ.0) GOTO 133
       DO 132 I=1,NDEFD
       IF (LBDEFD(I).EQ.IOB160(17:24)) GOTO 135
  132  CONTINUE
C  -     ADD NEW 'FOR' LABEL, AND PROCESS COMMAND
  133  NDEFD=NDEFD+1
       LBDEFD(NDEFD)=IOB160(17:24)
       IF (BLANKC) GOTO 100
       GOTO 180
C  -     MATCHES PREVIOUS 'FOR' LABEL.  BYPASS PROCESSING
  135  IF (BLANKC) GOTO 170
       GOTO 100
C
C      ADD NEW CONDITION, AFTER CHECKING TO SEE NOT DUPLICATE
C
  140  IF (NCOND.EQ.0) GOTO 144
       DO 142 I=1,NCOND
       IF (IOB160(9:16).EQ.LBCOND(I)) GOTO 100
  142  CONTINUE
  144  NCOND=NCOND+1
       LBCOND(NCOND)=IOB160(9:16)
       GOTO 100
C
C      '.UNITS' PROCESSING.  FOR REACTION INPUT, 'UNITS=PPM'
C              CONVERTS UNITS, ASSUMED TO BE CMS UPON INPUT
C              INTO PPM-MIN UNITS.  '.UNITS=OK' CANCELS
C              '.UNITS=PPM' COMMAND
C	'.UNITS=EA:DEGK' HAS EA UNITS INPUT IN DEG K UNITS,
C	'.UNITS=EA:KCAL' HAS EA UNITS IN KCAL (DEFAULT).
C
  150  IF (IOB160(13:16).EQ.' PPM') GOTO 154
       IF (IOB160(13:16).EQ.'  OK') GOTO 152
       IF (IOB160(9:16).EQ.' EA:DEGK') GOTO 156
       IF (IOB160(9:16).EQ.' EA:KCAL') GOTO 157
       IF (IOB160(9:16).EQ.' K-NOT-A') GOTO 158
       IF (IOB160(9:16).EQ.' A-NOT-K') GOTO 159
       WRITE (OUT,151) IOB160(9:16)
  151  FORMAT (' UNRECOGNIZED ''.UNITS'' SUBFIELD = ''',A8,'''')
       NERR=NERR+1
       WRITE (ICRT,151) IOB160(9:16)
  152  PPM=.FALSE.
       GOTO 100
  154  PPM=.TRUE.
       GOTO 100
  156  EADEGK=.TRUE.
       GOTO 100
  157  EADEGK=.FALSE.
       GOTO 100
  158  KNOTA=.TRUE.
       GOTO 100
  159  KNOTA=.FALSE.
       GOTO 100
C
C      '. ' FIELD TO BE BYPASSED
C
  170  CALL INBUF ('BYPASS  :',8)
       IF (IORET.EQ.2) GOTO 1999
       IF (IOLEN.EQ.0) GOTO 170
       IF (IOB160(1:2).EQ.'. ') GOTO 1
       GOTO 170
C
C      DETERMINE cmd
C
  180	IF (IOB160(5:8).EQ.'.CON') THEN
		IND=1
		GOTO 200
	ELSEIF (IOB160(5:8).EQ.'.BLD'.OR.IOB160(5:8).EQ.'.SLO') THEN
		IND=2
		GOTO 200
	ELSEIF (IOB160(5:8).EQ.'.STS') THEN
		IND=5
		GOTO 200
	ELSEIF (IOB160(5:8).EQ.'.ACT') THEN
		IND=4
		GOTO 200
	ELSEIF (IOB160(5:8).EQ.'.DUM') THEN
		IND=3
		GOTO 200
	ELSEIF (IOB160(3:8).EQ.'.NODIL') THEN
		IND=7
		GOTO 200
	ELSEIF (IOB160(5:8).EQ.'.DEP') THEN
		IF (INDDF.EQ.0) THEN
			IF (NCOEFV.GE.NCOC1) STOP 'TOO MANY V.COEF''S'
			NCOEFV=NCOEFV+1
			COEFNM(NCOEFV)='DEP.FAC'
			COEF(NCOEFV)=1.0
			INDDF=NCOEFV
		ENDIF
		IF (AIRSHD) THEN
			IND=-1
			GOTO 200
		ELSE
			GOTO 183
		ENDIF
	ELSEIF (IOB160(5:8).EQ.'.EMI') THEN
		IF (AIRSHD) THEN
			IND=-2
			GOTO 200
		ELSE
			GOTO 183
		ENDIF
	ENDIF
C
	IF (IOB160(5:8).EQ.'.RXN') GOTO 1000
	IF (IOB160(5:8).EQ.'.COE') GOTO 1200
	IF (IOB160(4:8).EQ.'.COEF') GOTO 1200
	IF (IOB160(4:8).EQ.'.VTCO') GOTO 1700
C
C        1      2      3
C      '.#C1','.#D1','.#PS'
C
	DO 181 IV=1,3
	IF (IOB160(5:8).EQ.VCOCMD(IV)) GOTO 400
  181	CONTINUE
C
	IF (IOB160(5:8).EQ.'.END') GOTO 2000
C
       WRITE (OUT,189) IOB160(5:8)
  189  FORMAT (' UNRECOGNIZED RDRXN COMMAND = ''',A4,'''')
       NERR=NERR+1
       IF (OUT.NE.1) WRITE (ICRT,189) IOB160(5:8)
       GOTO 100
C
  183	WRITE (OUT,188) IOB160(5:8)
  188	FORMAT (' ''',A4,''' ILLEGAL; ''AIRSHED'' NOT SPECIFIED.')
	IF (OUT.NE.1) WRITE (ICRT,188) IOB160(5:8)
	NERR=NERR+1
	GOTO 100
C
C      SPECIES DEFINITION ... READ NEXT SPECIES
C
  200	CALL INBUF ('SPECIE :',8)
	IF (IORET.EQ.2) GOTO 1999
	IF (IOLEN.EQ.0) GOTO 200
	IF (IOB160(1:1).EQ.'!'.OR.IOB160(1:1).EQ.' ') GOTO 200
	IF (IOB160(1:1).EQ.'.') GOTO 1
	IF (IOB160(1:1).EQ.'='.OR.IOB160(1:2).EQ.' =') GO TO 220
C
	CALL PARSE0 (5,IOB160,80)
	CALL PARSE1 (1,IOBF16,I,16,IOB160)
	CALL SPCNAM(I2,IOBF16,.FALSE.)		! FALSE TO INDICATE NOT RX LIST
	IF (IND.EQ.1) THEN
C		CALL PARSR2 (2,CONC0(I2),1.0,ERRIND,IOB160)	! OLD DEFAULT CONST C0=1
		CALL PARSR2 (2,CONC0(I2),0.0,ERRIND,IOB160)	! NOW DEFAULT CONST C0=0
		IF (ERRIND) CONC0(I2)=0.0
	ELSE
		CALL PARSR2 (2,CONC0(I2),0.0,ERRIND,IOB160)
		IF (ERRIND) CONC0(I2)=0.0
	ENDIF
	CALL PARSR2 (3,MWT(I2),0.0,ERRIND,IOB160)
	IF (ERRIND) THEN
		MWT(I2)=0.0
	ELSEIF (MWT(I2).NE.0.0) THEN
		CALL PARSR2 (4,CNO(I2),0.0,ERRIND,IOB160)
		IF (ERRIND) GOTO 202
		CALL PARSI2 (5,NNO(I2),0,ERRIND,IOB160)
		IF (ERRIND) GOTO 202
	ENDIF
	IF (IND.EQ.1.AND.NAME(I2).EQ.'M') INDM=I2
	GOTO 200
  202	WRITE (OUT,*) 'ERROR: Bad species parameter input ignored.'
	WRITE (OUT,*) 'Bad line = ',IOB160(1:LNBLNK(IOB160))
	NERR=NERR+1
	GOTO 200
C  -     SPECIES INPUT AS 'PRODUCT' LIST
  220  I2=0
       CALL RXLST2 (IOB160,I2)
       IF (I2.GT.0) GOTO 200
       IF (IORET.EQ.2) GOTO 1999
       WRITE (ICRT,228) IOB160
  228  FORMAT (' ERROR IN READING REACTANT LIST GIVEN BELOW.'
     &  /' ',A80)
       GOTO 200
C
C      DETERMINE TYPE OF INSERTED CODE
C
  300  IF (IOB160(9:16).EQ.'    INIT') THEN
             IV=4
       ELSEIF (IOB160(9:16).EQ.'    DIFF') THEN
             IV=5
       ELSEIF (IOB160(9:16).EQ.'    SAVE') THEN
             IV=6
       ELSE
             WRITE (OUT,311) IOB160(1:16)
  311        FORMAT (' UNRECOGNIZED TYPE FOR INSERTED CODE. INPUT=',
     &        A16,'.  COMMANDS FOR INSERTED CODE WILL BE IGNORED.')
             IF (OUT.NE.1) WRITE (ICRT,311) IOB160(1:16)
             IV=-1
             NERR=NERR+1
       ENDIF
C
C      READ IN VCOEF COMMANDS (FOR INSERTED CODE) AND SAVE IN
C      TEMPORARY FILE  (TYPE = IV)
C
  400  IF (IV.GT.0) THEN
               VCOCAL(IV)=.TRUE.
               IF (.NOT.VCODFD) THEN
                       IOB160=' '
        	       CALL FILNAM (NLEN,IOB160,TMPUIC,'VCOPRP.TMP ',' ')
C-VBF
C.	               OPEN (UNIT=UNIT1,NAME=IOB160,TYPE='NEW',DISP='DELETE')
C-I
	               OPEN (UNIT=UNIT1,FILE=IOB160,STATUS='UNKNOWN')
C-
	               VCODFD=.TRUE.
               ENDIF
       ENDIF
  410  CALL INBUF ('V.COEF :',8)
       IF (IORET.EQ.2) GOTO 1999
       IF (IOLEN.EQ.0) GOTO 410
       IF (IOB160(1:1).EQ.'!') GOTO 410
       IF (IOB160(1:1).EQ.'.') GOTO 1
C       IF (IOB160(1:4).EQ.'    ') GOTO 410
       IF (NOPRP.OR.IV.EQ.-1) GOTO 410
       WRITE (UNIT1,411) IV,(BYT160(I),I=1,IOLEN)
  411  FORMAT (I1,128A1,128A1)
       GOTO 410
C
C      INPUT REACTION LIST
C
 1000  IND=6
       NPRODS(1)=1
       IF (.NOT.RXOPN) THEN
                IOB160=' '
		CALL FILNAM (NLEN,IOB160,TMPUIC,'PREP.TMP ',' ')
C
		OPEN (UNIT=UNIT3,FILE=IOB160,STATUS='UNKNOWN',
     &		 FORM='UNFORMATTED')
C-
		RXOPN=.TRUE.
		ENDIF
C
 1001  CALL INBUF ('REACTN :',8)
       IF (IORET.EQ.2) GOTO 1999
       IF (IOLEN.EQ.0) GOTO 1001
       IF (IOB160(1:1).EQ.'!') GOTO 1001
       IF (IOB160(1:1).EQ.'.') GOTO 1
C
	NRXN=NRXN+1
        NRXNLN=1
C                           !NO. OF RXN LINES FOR CURRENT RXN
	IF (NRXN.GT.MAXRXN) THEN
		I=MAXRXN
		WRITE (OUT,*) 'TOO MANY REACTIONS.  MAX =',I
		STOP 'TOO MANY REACTIONS'
		ENDIF
C
C  -     DECODE RXN PARMS
C        EXPECTED INPUT:  cccc) a,ea,b ;rxn
C                     OR  cccc: a,ea,b
C        WHERE cccc = REACTION LABEL, a = ARRHENIUS A FACTOR,
C        ea = ACTIVATION ENERGY (OR BLANK), b = B FACTOR FOR
C        TEMPERATURE DEPENDENCE (OR BLANK), rxn = REACTION STRING.
C        LEADING BLANKS OK.
C
       DUMRXN=.FALSE.
       RKBUF=' '
       J=0
C -    GET PAST LEADING BLANKS
       DO 1003 I=1,IOLEN
       IF (BYT160(I).NE.' ') GOTO 1004
 1003  J=J+1
	GOTO 1001
C	         			! TOTALLY BLANK RECORD
 1004	JP=J+1
C    	                              !FIRST NON-BLANK CHAR
	DO 1005 L=JP,IOLEN
	IF (BYT160(L).EQ.';') GOTO 1006
 1005	RKBF1(L-J)=BYT160(L)
C    	                              !COPY STRING UP TO ';' INTO RKBUF
	DUMRXN=.TRUE.
C	             			! IF NO ';', THEN THIS IS 'DUMMY'
	NRTOSR(NRXN)=-1
 1006	L=L+1
	CALL ALIN16 (5,RKBUF)
	IF (RKBF1(16).NE.')') GOTO 1090
	RKBF1(16)=' '
C	                            !GET RID OF ')'
	CALL MOVLFT (RKBUF(1:16))
	LBL=RKBUF(1:4)
        IF ((LBL.EQ.'R   ').OR.(LBL.EQ.'    ').OR.(LBL.EQ.'R?  ')) THEN
		MAXRLB=MAXRLB+1
		WRITE (LBL,'(I4)') MAXRLB
		IF (MAXRLB<1000) LBL(1:1)='R'
	ENDIF
	IF (NRXN.GT.1) THEN
		DO 1107 I=1,NRXN-1
		IF (RXNLBL(I).EQ.LBL) THEN
			WRITE (ICRT,*) 'DUPLICATE REACTION LABEL: ',LBL
			WRITE (OUT,*) 'DUPLICATE REACTION LABEL: ',LBL
			GOTO 1108
		ENDIF
 1107		CONTINUE
 1108		CONTINUE
	ENDIF
	RXNLBL(NRXN)=LBL
C
C	DETERMINE TYPE OF KINETICS
C
	IF (RKBUF(28:32).EQ.'CONST') THEN
C		CONSTANT REACTION 'CONST=k'
		ITYP=3
		LKBUF(NRXN)=KBFEND
C		                  		! STORED FROM END OF KPBUF
		READ (RKBUF,1101,ERR=1090) KPRMIN(1)
 1101		FORMAT (32X,G16.0)
		KBFEND=KBFEND-1
C
	ELSEIF (RKBUF(29:32).EQ.'  PF' .OR. RKBUF(29:32).EQ.'PHOT')
     &	 THEN
C		PHOTOLYSIS REACTION 'PF=filename' OR  'PHOT=name'
		ITYP=7
		CALL MOVLFT (RKBUF(33:40))
		IF (NPHOTK.NE.0) THEN
                       DO 1011 I=1,NPHOTK
                       IF (RKBUF(33:40).EQ.PHOTNM(I)) THEN
                          LKBUF(NRXN)=I
                          GOTO 1014
C                                  		! DO NOTHING ELSE
                       ENDIF
 1011                  CONTINUE
		ENDIF
		IF (NPHOTK.EQ.MAXPHK) STOP 'TOO MANY PHOTOLYSIS SETS'
		NPHOTK=NPHOTK+1
		PHOTNM(NPHOTK)=RKBUF(33:40)
		LKBUF(NRXN)=NPHOTK
C						! THIS TYPE, WHICH IS THIS RXN.
 		PFTYPE(NPHOTK)=(RKBUF(29:32).EQ.'PHOT')
C		- ADD NEW COEFFICIENT FOR THIS PHOT TYPE.
		DO 1012 I=1,NCOEFV
		IF (COEFNM(I).EQ.RKBUF(33:40)) THEN
			IPHOTR(NPHOTK)=I
			GOTO 1014
		ENDIF
 1012		CONTINUE
		IF (NCOEFV.GE.NCOC1) THEN
			WRITE (ICRT,*) 'INCREASE MAXVCD (1).',
     &			 ' NCOC1, NCOEFV=',NCOEFV,NCOC1
			STOP 'TOO MANY VARIABLE COEF''S'
		ENDIF
		NCOEFV=NCOEFV+1
		COEFNM(NCOEFV)=RKBUF(33:40)
		IPHOTR(NPHOTK)=NCOEFV
 1014		CONTINUE
C
	ELSEIF (RKBUF(29:32).EQ.'COEF') THEN
C
C		K=COEFFICIENT.
C
		ITYP=8
		CALL MOVLFT (RKBUF(33:40))
C		- ADD NEW COEFFICIENT FOR THIS RATE CONSTANT.
		DO 1016 I=1,NCOEFV
		IF (COEFNM(I).EQ.RKBUF(33:40)) THEN
			LKBUF(NRXN)=I
			GOTO 1017
		ENDIF
 1016		CONTINUE
		IF (NCOEFV.GE.NCOC1) THEN
			WRITE (ICRT,*) 'INCREASE MAXVCD (2).',
     &			 ' NCOC1, NCOEFV=',NCOEFV,NCOC1
			STOP 'TOO MANY VARIABLE COEF''S'
		ENDIF
		NCOEFV=NCOEFV+1
		COEFNM(NCOEFV)=RKBUF(33:40)
		LKBUF(NRXN)=NCOEFV
 1017		CONTINUE
C
	ELSEIF (RKBUF(28:32).EQ.'SAMEK') THEN
C		'SAMEK=rxnlbl' :  SAME RATE CONST AS ANOTHER RXN
		ITYP=0
		GOTO 1110
C
	ELSEIF (RKBUF(27:32).EQ.'CASEOF') THEN
C		'CASEOF=rxnlbl' :  RATECON = RATE OF ANOTHER RXN
		ITYP=1
C
 1110		CALL MOVLFT (RKBUF(33:48))
		LBL2=RKBUF(33:36)
		IF (NRXN.GT.1) THEN
			DO 1111 I=1,NRXN-1
			IF (LBL2.EQ.RXNLBL(I)) GOTO 1112
 1111			CONTINUE
		ENDIF
		WRITE (OUT,*) 'REACTION LABEL = ',LBL2,' NOT FOUND'
		GOTO 1090
 1112		IF (RXTYP(I).EQ.0) THEN
			I=LKBUF(I)
		ELSEIF (RXTYP(I).LT.3) THEN
			WRITE (OUT,*) 'REF''D REACTION OF THE WRONG TYPE'
			GOTO 1090
		ENDIF
		LKBUF(NRXN)=I
C
	ELSEIF (RKBUF(26:32).EQ.'FALLOFF') THEN
C		'FALLOFF' : TROE-TYPE FALLOFF USED TO DEFINE RATE CON.
C			NEED TO READ PARMS LATER
		ITYP=5
		LKBUF(NRXN)=LOCKBF+1
		LOCKBF=LOCKBF+8
C
	ELSEIF (RKBUF(25:32).EQ.'K1+K2[M]') THEN
C		'K1+K2[M]': SPECIAL PRESSURE-DEPENDENCE EXPRESSION
C		NEED TO READ PARMS LATER
		ITYP=9
		LKBUF(NRXN)=LOCKBF+1
		LOCKBF=LOCKBF+6
C
	ELSEIF (RKBUF(18:32).EQ.'K0+K3M/1+K3M/K2') THEN
C		'K0+K3M/(1+K3M/K2)': SPECIAL PRESSURE-DEPENDENCE EXPRESSION
C		NEED TO READ PARMS LATER
		ITYP=10
		LKBUF(NRXN)=LOCKBF+1
		LOCKBF=LOCKBF+9
C
	ELSEIF (RKBUF(28:32).EQ.'LTEMP') THEN
C		'LTEMP' : K CALCULATED FOR TEMPERATURE BY LINEAR
C			EXTRAPOLATION OF K'S DEFINED FOR T'S SPECIFIED.
		ITYP=6
		READ (RKBUF,1008,ERR=1090) NJRXN
 1008		FORMAT (32X,I16)
		IF (NJRXN.LE.0) GOTO 1090
		LOCIBF=LOCIBF+2
		IF (LOCIBF.GT.MAXIKB) STOP 'MAXIKB TOO SMALL'
		LKBUF(NRXN)=LOCIBF-1
		IKPBUF(LOCIBF-1)=LOCKBF+1
		IKPBUF(LOCIBF)=NJRXN
	ELSE
C		DEFAULT:  READ A, EA, B
		ITYP=4
		LKBUF(NRXN)=LOCKBF+1
		LOCKBF=LOCKBF+3
		READ (RKBUF,1007,ERR=1090) KPRMIN(1),KPRMIN(2),KPRMIN(3)
 1007		FORMAT (16X,3G16.0)
		IF (TRCONV.NE.1.0.AND.KPRMIN(3).NE.0.0) KPRMIN(1)=
     &		 KPRMIN(1)*(TRCONV**KPRMIN(3))
		IF (EADEGK) KPRMIN(2)=KPRMIN(2)*0.0019872
		IF (KNOTA.AND.KPRMIN(2).NE.0.0)
     &		 KPRMIN(1)=KPRMIN(1)*EXP(KPRMIN(2)/(0.0019872*TEMPR))
       ENDIF
C
C	PROCESS "FAC=nn" OR "QY=nn".  CAN APPEAR WITH PF=NAME, COEF=NAME, ETC.
C	SO WILL BE IN FIELDS 4 AND 5
C
	IF (RKBUF(63:64).EQ.'QY'.OR.RKBUF(62:64).EQ.'FAC') THEN
		IOBF16=RKBUF(65:80)
		CALL COFNAM(INDQYF,.FALSE.)
	ELSE
		INDQYF=0
	ENDIF
C
 1019  IF (.NOT.DUMRXN) THEN
		J=0
		DO 1018 I=L,IOLEN
		ILCHAR=ICHAR(BYT160(I))
		J=J+1
		IF (ILCHAR.NE.9) THEN
			TMPRXN(J:J)=BYT160(I)
		ELSE
C			K=8-IMOD(J,8)-1
C			                     !ASSUMES ';' AT TAB POS
C			TMPRXN(J:J+K)='        '
C			                          	!CONVERT TABS TO SPACES
C			J=J+K
			TMPRXN(J:J)=' '
		ENDIF
 1018		CONTINUE
		IOB160=TMPRXN
		IOLEN=J
C
		IF (YESPRP) WRITE (UNIT3) NEWRXN,J,IOB160(1:IOLEN)
                OUTBUF=' '
		WRITE (OUTBUF,1021) LBL,IOB160(1:IOLEN)
 1021		FORMAT (A4,') ',A)
                LOUTBF=J+6
		IRTOSR(2,NRXN)=0
		IRTOSR(3,NRXN)=0
		INDEXP=NPRODS(NRXN)-1
C		                     		!LAST INDEX USED IN IPRODS
		CALL RXLST1 (BYT160,NRTOSR(NRXN),INDEXP,NRXNLN)
		NPRODS(NRXN+1)=INDEXP+1
		EOF=IORET.EQ.2
		IF (NRTOSR(NRXN).EQ.0) GOTO 1092
		IF (INDQYF.NE.0) THEN
			IF (NRTOSR(NRXN).EQ.MAXRCT) GOTO 1092
			NRTOSR(NRXN)=NRTOSR(NRXN)+1
			IRTOSR(NRTOSR(NRXN),NRXN)=INDQYF
		ENDIF
	ELSE
C	                               !WRITE BLANK RXN STRING IF DUMMY RXN
		IF (YESPRP) WRITE (UNIT3) NEWRXN,1,' '
                OUTBUF=' '
		WRITE (OUTBUF,1022) LBL
 1022		FORMAT (A4,') (NO REACTION)')
                LOUTBF=19
		IRTOSR(1,NRXN)=0
		IRTOSR(2,NRXN)=0
		IRTOSR(3,NRXN)=0
		NPRODS(NRXN+1)=NPRODS(NRXN)
		IORDR=0
	ENDIF
	RXTYP(NRXN)=ITYP
C
C	READ IN PARMS FOR 'FALLOFF' OR 'LTEMP' RUN TYPE.
C
	IF (ITYP.EQ.6) THEN
		DO 1080 JX=1,NJRXN
		CALL INBUF (' LTEMP: ',8)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (2,IOB160)
C		                      		! INPUT:  RXN LBL, TEMPERATURE
		CALL MOVLFT (IOB160(1:16))
		LBL2=IOB160(1:4)
		IF (NRXN.GT.1) THEN
			DO 1082 I=1,NRXN-1
			IF (LBL2.EQ.RXNLBL(I)) GOTO 1083
 1082			CONTINUE
		ENDIF
		WRITE (OUT,*) 'REACTION LABEL = ',LBL2,' NOT FOUND'
		GOTO 1090
 1083		IF (RXTYP(I).LT.3) THEN
			WRITE (OUT,*) 'REF''D REACTION OF THE WRONG TYPE'
			GOTO 1090
		ENDIF
		LOCIBF=LOCIBF+1
		IF (LOCIBF.GT.MAXIKB) STOP 'MAXIKB TOO SMALL'
		IKPBUF(LOCIBF)=I
C		                		! REF'D RXN NO IN BUFFER
		LOCKBF=LOCKBF+1
 1080		READ (IOB160,1007,ERR=1057) KPBUF(LOCKBF)
C    		                                              	! READ TEMP
	ELSEIF (ITYP.EQ.5) THEN
		CALL INBUF ('FALLOFF:  K0 = ',15)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (3,IOB160)
		READ (IOB160,'(3G16.0)',ERR=1057) KPRMIN(1),KPRMIN(2),
     &		 KPRMIN(3)
		IF (TRCONV.NE.1.0.AND.KPRMIN(3).NE.0.0) KPRMIN(1)=
     &		 KPRMIN(1)*(TRCONV**KPRMIN(3))
		IF (EADEGK) KPRMIN(2)=KPRMIN(2)*0.0019872
		IF (KNOTA.AND.KPRMIN(2).NE.0.0)
     &		 KPRMIN(1)=KPRMIN(1)*EXP(KPRMIN(2)/(0.0019872*TEMPR))
		CALL INBUF ('FALLOFF:  KI = ',15)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (3,IOB160)
		READ (IOB160,'(3G16.0)',ERR=1057) KPRMIN(4),KPRMIN(5),
     &		 KPRMIN(6)
		IF (TRCONV.NE.1.0.AND.KPRMIN(6).NE.0.0) KPRMIN(4)=
     &		 KPRMIN(4)*(TRCONV**KPRMIN(6))
		IF (EADEGK) KPRMIN(5)=KPRMIN(5)*0.0019872
		IF (KNOTA.AND.KPRMIN(2).NE.0.0)
     &		 KPRMIN(4)=KPRMIN(4)*EXP(KPRMIN(5)/(0.0019872*TEMPR))
		CALL INBUF ('FALLOFF: F,N = ',15)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (2,IOB160)
		READ (IOB160,'(2G16.0)',ERR=1057) KPRMIN(7),KPRMIN(8)
		IF (KPRMIN(8).EQ.0.0) KPRMIN(8)=1.0
C
	ELSEIF (ITYP.EQ.9) THEN
		CALL INBUF ('K1+K2[M]: K1 = ',15)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (3,IOB160)
		READ (IOB160,'(3G16.0)',ERR=1057) KPRMIN(1),KPRMIN(2),
     &		 KPRMIN(3)
		IF (TRCONV.NE.1.0.AND.KPRMIN(3).NE.0.0) KPRMIN(1)=
     &		 KPRMIN(1)*(TRCONV**KPRMIN(3))
		IF (EADEGK) KPRMIN(2)=KPRMIN(2)*0.0019872
		IF (KNOTA.AND.KPRMIN(2).NE.0.0)
     &		 KPRMIN(1)=KPRMIN(1)*EXP(KPRMIN(2)/(0.0019872*TEMPR))
		CALL INBUF ('K1+K2[M]: K2 = ',15)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (3,IOB160)
		READ (IOB160,'(3G16.0)',ERR=1057) KPRMIN(4),KPRMIN(5),
     &		 KPRMIN(6)
		IF (TRCONV.NE.1.0.AND.KPRMIN(6).NE.0.0) KPRMIN(4)=
     &		 KPRMIN(4)*(TRCONV**KPRMIN(6))
		IF (EADEGK) KPRMIN(5)=KPRMIN(5)*0.0019872
		IF (KNOTA.AND.KPRMIN(5).NE.0.0)
     &		 KPRMIN(4)=KPRMIN(4)*EXP(KPRMIN(5)/(0.0019872*TEMPR))

C
	ELSEIF (ITYP.EQ.10) THEN
		CALL INBUF ('K0+K3M/(1+K3M/K2): K0 = ',24)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (3,IOB160)
		READ (IOB160,'(3G16.0)',ERR=1057) KPRMIN(1),KPRMIN(2),
     &		 KPRMIN(3)
		IF (TRCONV.NE.1.0.AND.KPRMIN(3).NE.0.0) KPRMIN(1)=
     &		 KPRMIN(1)*(TRCONV**KPRMIN(3))
		IF (EADEGK) KPRMIN(2)=KPRMIN(2)*0.0019872
		IF (KNOTA.AND.KPRMIN(2).NE.0.0)
     &		 KPRMIN(1)=KPRMIN(1)*EXP(KPRMIN(2)/(0.0019872*TEMPR))
		CALL INBUF ('K0+K3M/(1+K3M/K2): K1 = ',24)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (3,IOB160)
		READ (IOB160,'(3G16.0)',ERR=1057) KPRMIN(4),KPRMIN(5),
     &		 KPRMIN(6)
		IF (TRCONV.NE.1.0.AND.KPRMIN(6).NE.0.0) KPRMIN(4)=
     &		 KPRMIN(4)*(TRCONV**KPRMIN(6))
		IF (EADEGK) KPRMIN(5)=KPRMIN(5)*0.0019872
		IF (KNOTA.AND.KPRMIN(5).NE.0.0)
     &		 KPRMIN(4)=KPRMIN(4)*EXP(KPRMIN(5)/(0.0019872*TEMPR))
		CALL INBUF ('K0+K3M/(1+K3M/K2): K2 = ',24)
		IF (IORET.EQ.2) GOTO 1056
		CALL ALIN16 (3,IOB160)
		READ (IOB160,'(3G16.0)',ERR=1057) KPRMIN(7),KPRMIN(8),
     &		 KPRMIN(9)
		IF (TRCONV.NE.1.0.AND.KPRMIN(6).NE.0.0) KPRMIN(7)=
     &		 KPRMIN(7)*(TRCONV**KPRMIN(6))
		IF (EADEGK) KPRMIN(8)=KPRMIN(8)*0.0019872
		IF (KNOTA.AND.KPRMIN(8).NE.0.0)
     &		 KPRMIN(7)=KPRMIN(7)*EXP(KPRMIN(8)/(0.0019872*TEMPR))

	ENDIF
	GOTO 1060
C
C	ERROR READING ADDED PARMS
 1056	WRITE (OUT,*) '<EOF> WHEN ADDED KINETIC PARMS EXPECTED'
	GOTO 1059
 1057	WRITE (OUT,*) 'INPUT ERROR ADDED KINETIC PARMS EXPECTED'
 1059	NERR=NERR+1

C
C	DETERMINE IORDR = NUMBER OF NON-COEFFICIENT REACTANTS
C	AND CONVERT UNITS, IF NECESSARY
C
 1060	IORDR=0
	KEQ=.FALSE.
	IF (.NOT.PPM) GOTO 1030
CD       WRITE (OUT,*) 'ITYP= ',ITYP,'   NRTOSR(NRXN)=',NRTOSR(NRXN)
	IF (ITYP.LT.3.OR.(ITYP.GT.5.AND.ITYP.LT.9)) GOTO 1030
	NRI=NRTOSR(NRXN)
	IF (NRI.LE.0) GOTO 1030
	DO 1032 J=1,NRI
	IR=IRTOSR(J,NRXN)
	IF (IR.GT.0) THEN
		IORDR=IORDR+1
CD		WRITE (OUT,*) 'IORDR=IORDR+1= ',IORDR
	ELSEIF (-IR.GT.MAXMAX) THEN
		KEQ=.TRUE.
C		          			! REF'S K OF ANOTHER RXN,
		JRXN=-(IR+MAXMAX)
C		                 		! SO SUBTRACT OFF THAT ORDER
		IF (RXTYP(JRXN).EQ.7) THEN
			IORDR=IORDR-1
C			             		! ALL PHOT RXNS ORDER=1
CD			WRITE (OUT,*) 'RXTYP=7, IORDR= ',IORDR
		ELSE
			NRJ=NRTOSR(JRXN)
			DO 1034 I=1,NRJ
			IR=IRTOSR(I,JRXN)
			IF (IR.GT.0) THEN
				IORDR=IORDR-1
CD				WRITE (OUT,*) 'IORDR=IORDR-1= ',IORDR
			ELSEIF (-IR.GT.MAXMAX) THEN
				WRITE (OUT,*) 'CAN''T CONVERT UNITS'
     &				 ,'FOR THIS REACTION.'
				WRITE (OUT,*) 'REF''S REACTION WHICH'
     &				 ,'REF''S ANOTHER'
				GOTO 1090
			ENDIF
 1034			CONTINUE
		ENDIF
	ELSE
C		Coef's starting with "*" are treated as species for computing order
		IF (COEFNM(-IR)(1:1).EQ.'*') IORDR=IORDR+1
	ENDIF
 1032	CONTINUE
C  -     *NOTE*  CONVERSION FACTORS ARE FOR CONVERTING CMS UNITS INPUT
C                TO PPM-MIN UNITS.  VALID FOR 1 ATM PRESSURE ONLY.
C       CONV(1)=60.0
C       CONV(2)=4.40373E+17/TREF
C       CONV(3)=3.23206E+33/(TREF*TREF)
C
CD       WRITE (OUT,*) 'AFTER 1032 LOOP, IORDR= ',IORDR
	IF (IORDR.EQ.0) GOTO 1030
	IF (KEQ) THEN
		FAC=1.0
C		       		! EQUILIBRIUM CONSTANT
	ELSE
		FAC=60.0
C		        	! RATE CONSTANT.  TAKE INTO ACCOUNT TIME UNITS
		IORDR=IORDR-1
C		             	! AND CONC UNITS = ORDER-1
	ENDIF
	IF (IORDR.NE.0) FAC=FAC*(7.3395E+15/TREF)**(IORDR)
CD       WRITE (OUT,*) 'FAC= ',FAC
C
	IF (ITYP.EQ.3) THEN
		KPRMIN(1)=KPRMIN(1)*FAC
	ELSEIF (ITYP.EQ.4) THEN
		KPRMIN(1)=KPRMIN(1)*FAC
		KPRMIN(3)=KPRMIN(3)-FLOAT(IORDR)
	ELSEIF (ITYP.EQ.5) THEN
		KPRMIN(1)=FAC*(7.3395E+15/TREF)*KPRMIN(1)
		KPRMIN(3)=KPRMIN(3)-FLOAT(IORDR+1)
		KPRMIN(4)=FAC*KPRMIN(4)
		KPRMIN(6)=KPRMIN(6)-FLOAT(IORDR)
	ELSEIF (ITYP.EQ.9) THEN
		KPRMIN(1)=FAC*KPRMIN(1)
		KPRMIN(3)=KPRMIN(3)-FLOAT(IORDR)
		KPRMIN(4)=FAC*(7.3395E+15/TREF)*KPRMIN(4)
		KPRMIN(6)=KPRMIN(6)-FLOAT(IORDR+1)
	ELSEIF (ITYP.EQ.10) THEN
		KPRMIN(1)=FAC*KPRMIN(1)
		KPRMIN(3)=KPRMIN(3)-FLOAT(IORDR)
		KPRMIN(4)=FAC*KPRMIN(4)
		KPRMIN(6)=KPRMIN(6)-FLOAT(IORDR)
		KPRMIN(7)=FAC*(7.3395E+15/TREF)*KPRMIN(7)
		KPRMIN(9)=KPRMIN(9)-FLOAT(IORDR+1)
	ENDIF
C
C	DONE WITH PARM INPUT AND PROCESSING.  WRITE THEM OUT.
C
 1030   IF (ITYP.EQ.3) THEN
		KPBUF(LKBUF(NRXN))=KPRMIN(1)
		WRITE (OUTBUF(73: ),1040) KPBUF(LKBUF(NRXN))
 1040		FORMAT (1PE11.3)
	ELSEIF (ITYP.EQ.7) THEN
		WRITE (OUTBUF(73: ),1041) RKBUF(33:40)
 1041		FORMAT (7X,'PHOT. = ',A8)
	ELSEIF (ITYP.EQ.8) THEN
		WRITE (OUTBUF(73:),'(7X,''COEF. = '',A8)') 
     &		 COEFNM(LKBUF(NRXN))
	ELSEIF (ITYP.EQ.0) THEN
		WRITE (OUTBUF(73: ),1042) RXNLBL(LKBUF(NRXN))
 1042		FORMAT (7X,'SAME K AS ',A4)
	ELSEIF (ITYP.EQ.1) THEN
		WRITE (OUTBUF(73: ),1043) RXNLBL(LKBUF(NRXN))
 1043		FORMAT (7X,'K = RATE OF ',A4)
	ELSEIF (ITYP.EQ.6) THEN
		WRITE (OUTBUF(73: ),1047)
 1047		FORMAT (7X,'K INTERPOLATED')
	ELSEIF (ITYP.EQ.4) THEN
		KPBUF(LOCKBF-2)=KPRMIN(1)
		KPBUF(LOCKBF-1)=KPRMIN(2)
		KPBUF(LOCKBF)=KPRMIN(3)
		WRITE (OUTBUF(73: ),1044) KPBUF(LOCKBF-2),
     &		 KPBUF(LOCKBF-1),KPBUF(LOCKBF)
 1044		FORMAT (1PE11.3,0PF7.2,F8.3)
	ELSEIF (ITYP.EQ.5) THEN
		KPBUF(LOCKBF-7)=KPRMIN(1)
		KPBUF(LOCKBF-6)=KPRMIN(2)
		KPBUF(LOCKBF-5)=KPRMIN(3)
		KPBUF(LOCKBF-4)=KPRMIN(4)
		KPBUF(LOCKBF-3)=KPRMIN(5)
		KPBUF(LOCKBF-2)=KPRMIN(6)
		KPBUF(LOCKBF-1)=KPRMIN(7)
		KPBUF(LOCKBF)=KPRMIN(8)
		WRITE (OUTBUF(73: ),1045) KPBUF(LOCKBF-1),
     &           KPBUF(LOCKBF)
 1045		FORMAT (' FALLOFF F=',F6.3,', N=',F6.3)
	ELSEIF (ITYP.EQ.9) THEN
		KPBUF(LOCKBF-5)=KPRMIN(1)
		KPBUF(LOCKBF-4)=KPRMIN(2)
		KPBUF(LOCKBF-3)=KPRMIN(3)
		KPBUF(LOCKBF-2)=KPRMIN(4)
		KPBUF(LOCKBF-1)=KPRMIN(5)
		KPBUF(LOCKBF)=KPRMIN(6)
		OUTBUF(73:)=' K = K1 + K2 [M]'
	ELSEIF (ITYP.EQ.10) THEN
		KPBUF(LOCKBF-8)=KPRMIN(1)
		KPBUF(LOCKBF-7)=KPRMIN(2)
		KPBUF(LOCKBF-6)=KPRMIN(3)
		KPBUF(LOCKBF-5)=KPRMIN(4)
		KPBUF(LOCKBF-4)=KPRMIN(5)
		KPBUF(LOCKBF-3)=KPRMIN(6)
		KPBUF(LOCKBF-2)=KPRMIN(7)
		KPBUF(LOCKBF-1)=KPRMIN(8)
		KPBUF(LOCKBF)=KPRMIN(9)
		OUTBUF(73:)=' K=K0+K3M/(1+K3M/K2)'
	ELSE
		WRITE (OUT,*) 'PGM ERR.  BAD ITYP =',ITYP
	ENDIF
        LOUTBF=100
	IF (.NOT.DUMRXN) THEN
              NP=NPRODS(NRXN+1)-NPRODS(NRXN)
              IF (NP.LE.3) THEN
 		  WRITE (OUTBUF(LOUTBF+1: ),1048) (IRTOSR(I,NRXN),I=1,3)
     &		   ,(IPRODS(I),I=NPRODS(NRXN),NPRODS(NRXN+1)-1)
 1048     	  FORMAT (3I4,' =',3I5)
                  WRITE (OUT,1051) OUTBUF
 1051             FORMAT (' ',A131)
              ELSE
                  WRITE (OUTBUF(LOUTBF+1: ),1048) (IRTOSR(I,NRXN),I=1,3)
     &		   ,(IPRODS(I),I=NPRODS(NRXN),NPRODS(NRXN)+2)
                  WRITE (OUT,1051) OUTBUF
		  WRITE (OUT,1050) (IPRODS(I),I=NPRODS(NRXN)+3,
     &              NPRODS(NRXN+1)-1)
 1050             FORMAT (100X,6I5)
              ENDIF
	ENDIF
	IF (ITYP.EQ.6) THEN
		LK=LKBUF(NRXN)+1
		J=IKPBUF(LK-1)-1
		J1=IKPBUF(LK)
		DO 1046 I=1,J1
 1046		WRITE (OUT,1089) RXNLBL(IKPBUF(LK+I)),KPBUF(J+I)
 1089		FORMAT (74X,'K(',A4,') USED WHEN T =',F7.0)
	ELSEIF (ITYP.EQ.5) THEN
		WRITE (OUT,1049) '0',KPBUF(LOCKBF-7),KPBUF(LOCKBF-6),
     &	 KPBUF(LOCKBF-5),'I',KPBUF(LOCKBF-4),KPBUF(LOCKBF-3),
     &	 KPBUF(LOCKBF-2)
 1049		FORMAT (70X,'K',A1,':',1PE11.3,0PF7.2,F8.3)
	ELSEIF (ITYP.EQ.9) THEN
		WRITE (OUT,1049) '1',KPBUF(LOCKBF-5),KPBUF(LOCKBF-4),
     &	 KPBUF(LOCKBF-3),'2',KPBUF(LOCKBF-2),KPBUF(LOCKBF-1),
     &	 KPBUF(LOCKBF)
	ELSEIF (ITYP.EQ.10) THEN
		WRITE (OUT,1049) '0',KPBUF(LOCKBF-8),KPBUF(LOCKBF-7),
     &	 KPBUF(LOCKBF-6),'2',KPBUF(LOCKBF-5),KPBUF(LOCKBF-4),
     &	 KPBUF(LOCKBF-3),'3',KPBUF(LOCKBF-2),KPBUF(LOCKBF-1),
     &	 KPBUF(LOCKBF)
	ENDIF
	IF (LOCKBF.GT.KBFEND) THEN
		WRITE (OUT,*) 'KINETIC PARM BUFFER LENGTH =',LOCKBF+
     &		 MAXKBF-KBFEND,' EXCEEDS PROGRAM DIMENSIONS'
		STOP 'TOO MANY RATE PARMS'
	ENDIF
	GO TO 1001
C	          			! DONE
C
C  -     ERROR
 1090  WRITE (OUT,1091) IOB160(1:IOLEN)
 1091  FORMAT (' REACTION PARM INPUT ERROR IN LINE GIVEN BELOW.'
     &  /' ',A)
       NERR=NERR+1
       WRITE (ICRT,1091) IOB160(1:IOLEN)
       GOTO 1095
 1092  WRITE (ICRT,1094) IOB160(1:IOLEN)
 1094  FORMAT (' REACTION LIST DECODING ERROR.  INPUT LINE BELOW:'
     &  /' ',A)
       IF (YESPRP) THEN
               DO 1096 I=1,NRXNLN
 1096          BACKSPACE UNIT3
       ENDIF
 1095  NRXN=NRXN-1
       IF (EOF) GOTO 2000
       GOTO 1001
C
C     VALUE OF VARIABLE COEFFICIENT READ IN    (DEFAULT VALUE = 0.0)
C
 1200	CALL INBUF ('COEFNT :',8)
	IF (IORET.EQ.2) GOTO 1999
	IF (IOLEN.EQ.0) GOTO 1200
	IF (IOB160(1:1).EQ.'!') GOTO 1200
	IF (IOB160(1:1).EQ.'.') GOTO 1
	IF (IOB160(1:8).EQ.'        ') GOTO 1200
	CALL PARSE0 (2,IOB160,80)
	CALL PARSE1 (1,IOBF16,I,8,IOB160)
	CALL PARSR2 (2,X,0.0,ERRIND,IOB160)
	IF (ERRIND) GOTO 1290
	IF (NCOEFV.EQ.0) GOTO 1206
	DO 1204 I=1,NCOEFV
	IF (IOBF16(1:8).EQ.COEFNM(I)) GOTO 1205
 1204	CONTINUE
 1206	NCOEFV=NCOEFV+1
	IF (NCOEFV.GE.NCOC1) THEN
		I=MAXCOV
		WRITE (OUT,*) 'TOO MANY VARIABLE COEFFICIENTS.  MAX =',I
		WRITE (ICRT,*) 'INCREASE MAXVCD (3).',
     &		 ' NCOC1, NCOEFV=',NCOEFV,NCOC1
		STOP 'TOO MANY VARIABLE COEFFICIENTS'
		ENDIF
	COEFNM(NCOEFV)=IOBF16(1:8)
	COEF(NCOEFV)=X
	GOTO 1200
 1205	COEF(I)=X
	GOTO 1200
 1290	WRITE (OUT,1291) IOB160
 1291	FORMAT (' COEF INPUT ERROR IN LINE GIVEN BELOW.'/' ',A80)
	NERR=NERR+1
	WRITE (ICRT,1291) IOB160
	GOTO 1200
C
C      PHOTOLYSIS DATA TO READ IN.  WRITE IT TO A TEMPORARY FILE
C
 1500  IOBF16=' '
       IOBF16=IOB160(9:16)
C                               ! NAME TO ASSOCIATE WITH THIS DATA SET
       CALL MOVLFT (IOBF16)
       IOB160=' '
	IF (SAVPHF) THEN
		CALL FILNAM (I,IOB160,TMPUIC,IOBF16,'.PHF ')
	ELSE
		CALL FILNAM (I,IOB160,TMPUIC,IOBF16,'.PTM ')
	ENDIF
C-VBS
C.       OPEN (UNIT=UNIT2,NAME=IOB160,TYPE='NEW')
C-I
       OPEN (UNIT=UNIT2,FILE=IOB160,STATUS='UNKNOWN')
C-
 1501  CALL INBUF ('PHOT   :',8)
       IF (IORET.EQ.2) THEN
              CLOSE (UNIT=UNIT2)
              GOTO 1999
       ENDIF
       IF (IOLEN.EQ.0 .OR. IOB160.EQ.' ') THEN
               CLOSE (UNIT=UNIT2)
               GOTO 100
       ENDIF
       IF (IOB160(1:1).EQ.'.') THEN
               CLOSE (UNIT=UNIT2)
               GOTO 1
       ENDIF
       WRITE (UNIT2,1510) IOB160(1:LNBLNK(IOB160))
 1510  FORMAT (A)
       GOTO 1501
C
C        .VTEMP COMMAND
C
 1600  READ (IOB160,1601,ERR=1680) NVT
 1601  FORMAT (8X,I8)
CD      WRITE (OUT,*) 'NO. OF TEMPS FOR VAR COEFS= ',NVT
       IF (NVT.GT.MXVTMP) THEN
		WRITE (OUT,1602) MXVTMP
 1602		FORMAT (' VALUE IN VTEMP COMMAND EXCEEDS MAXIMUM.',
     &		  '  MAX=',I3)
		NVT=MXVTMP
		NERR=NERR+1
       ENDIF
       IF (NVTEMP.NE.0.AND.NVT.NE.NVTEMP) THEN
C  -		NVTEMP PREVIOUSLY DEFINED, ERROR IF IT'S DIFFERENT NOW
		WRITE (OUT,1603) NVTEMP,NVT
 1603		FORMAT (' NO. OF TEMPS FOR VAR COEFS DIFFERENT ',
     &		  'THAN PREVIOUSLY DEFINED. OLD, NEW= ',2I4)
		STOP 'NVTEMP DIFFERENT THAN PREVIOUSLY DEFINED'
       ENDIF
C
C	 GET LINE OF TEMPERATURES
C
 1620  CALL INBUF ('VTEMP  :',8)
       IF (IORET.EQ.2) THEN
C                          		!EOF
		NERR=NERR+1
		WRITE (OUT,1604)
 1604		FORMAT (' MISSING LINE OF TEMPS AFTER .VTEMP COMMAND')
		GOTO 1999
       ENDIF
       IF (IOLEN.EQ.0) GOTO 1620
       CALL ALIN16(NVT,IOB160)
       DO 1610 I=1,NVT
         I1=(I-1)*16+1
         I2=I*16
         READ (IOB160(I1:I2),1605,ERR=1690) X
 1605    FORMAT (G16.0)
         IF (IOB160(I1:I2).EQ.' ') GOTO 1691
CD        WRITE (OUT,*) 'VTEMP VALUE: ',X
         IF (NVTEMP.NE.0) THEN
		IF (X.NE.VTEMP(I)) THEN
		  WRITE (OUT,1607) I,VTEMP(I),X
 1607		  FORMAT (' TEMPERATURE ',I2,' IN LIST DIFFERS FROM',
     & 		    ' PREVIOUS VTEMP COMMAND. OLD, NEW TEMP =',2F6.1)
		  STOP 'VTEMP DIFFERENT THAN PREVIOUSLY DEFINED'
      		ENDIF
	 ELSE
	         IF (I.GT.1) THEN
	 	    IF (X.LT.VTEMP(I-1)) THEN
			WRITE (OUT,1606) IOB160(1:80)
 1606			FORMAT (' TEMPS OUT OF ORDER IN LINE GIVEN ',
     &			  'BELOW.'/' ',A)
			NERR=NERR+1
		    ENDIF
         	 ENDIF
	         VTEMP(I)=X
CD		 WRITE (OUT,*) 'VTEMP(',I,')= ',VTEMP(I)
	 ENDIF
 1610  CONTINUE
C
       NVTEMP=NVT
CD      WRITE (OUT,1608) NVTEMP,(VTEMP(I),I=1,NVTEMP)
CD1608  FORMAT (1X,I3,' TEMPERATURES FOR VARIABLE COEFFICIENTS:',5X,
CD    &   6F7.1)
       GOTO 100
C
C      ERRORS
C
 1680  WRITE (OUT,1621)
 1621  FORMAT (' ERROR DECODING .VTEMP COMMAND')
       NERR=NERR+1
       NVT=MXVTMP
       GOTO 1620
 1690  WRITE (OUT,1622) IOB160(1:80)
 1622  FORMAT (' DECODING ERROR IN LINE AFTER .VTEMP COMMAND. INPUT',
     &   ' LINE BELOW:'/' ',A)
       NERR=NERR+1
       NVTEMP=NVT
       GOTO 100
 1691  WRITE (OUT,1623) IOB160(1:80)
 1623  FORMAT (' ERROR: NO. TEMPERATURES SPECIFIED < NVTEMP.  INPUT',
     &   ' LINE BELOW:'/' ',A)
       NERR=NERR+1
       NVTEMP=NVT
       GOTO 100
C
C        .VTCO COMMAND
C      EXPECTED INPUT: coef name, value(1), value(2), ..., value(NVTEMP)
C
 1700  NEWTVC=.TRUE.
       CALL INBUF ('VTCO   :',8)
       IF (IORET.EQ.2) GOTO 1999
       IF (IOLEN.EQ.0) GOTO 1700
       IF (IOB160(1:1).EQ.'.') GOTO 1
       IF (NVTEMP.EQ.0) THEN
  		WRITE (OUT,*) 'INPUT ERROR: .VTCO COMMAND BEFORE ',
     &           '.VTEMP COMMAND. VTCO NOT PROCESSED.'
		NERR=NERR+1
		GOTO 100
       ENDIF
       CALL ALIN16 (NVTEMP+1,IOB160)
       CALL MOVLFT(IOB160)
       IF (IOB160(1:8).EQ.'ERROR') GOTO 1792
       IF (NCOEFV.GT.0) THEN
	        DO 1710 IC=1,NCOEFV
       		IF (IOB160(1:8).EQ.COEFNM(IC)) GOTO 1715
 1710  		CONTINUE
       ENDIF
C  -	 ADD NEW VARIABLE COEFFICIENT
CD      WRITE (OUT,*) 'NEW TEMP VARYING COEF IS NEW VAR COEF'
       NCOEFV=NCOEFV+1
       NVTCO=NVTCO+1
       IF (NCOEFV.GE.NCOC1) THEN
		I=MAXCOV
		WRITE (ICRT,*) 'INCREASE MAXVCD (4).',
     &		 ' NCOC1, NCOEFV=',NCOEFV,NCOC1
		WRITE (OUT,*) 'TOO MANY VARIABLE COEFFICIENTS.  MAX =',I
		STOP 'TOO MANY VARIABLE COEFFICIENTS'
       ENDIF
       IF (NVTCO.GT.MXVTCO) THEN
		I=MXVTCO
		WRITE (OUT,*) 'TOO MANY TEMP VARYING COEFS.  MAX =',I
		STOP 'TOO MANY TEMPERATURE VARYING COEFFICIENTS.'
       ENDIF
       COEFNM(NCOEFV)=IOB160(1:8)
CD      WRITE (OUT,*) 'NEW COEF: COEFNM(',NCOEFV,')=',COEFNM(NCOEFV)
       COEF(NCOEFV)=0.0
       IVTCO(NVTCO)=NCOEFV
       IV=NVTCO
       GOTO 1730
C
 1715  IF (NVTCO.GT.0) THEN
	        DO 1720 IV=1,NVTCO
		IF (IVTCO(IV).EQ.IC) THEN
			NEWTVC=.FALSE.
			GOTO 1730
		ENDIF
 1720  		CONTINUE
       ENDIF
C  -    PREVIOUSLY DEFINED AS VAR COEF, BUT NOT AS TEMP VARYING COEF
CD      WRITE (OUT,*) 'OLD COEF NOW DEFINED AS TEMP VARYING COEF'
       NVTCO=NVTCO+1
       IVTCO(NVTCO)=IC
       IV=NVTCO
C
 1730  DO 1740 I=1,NVTEMP
         I1=I*16+1
         I2=(I+1)*16
         READ (IOB160(I1:I2),1705,ERR=1790) X
CC         READ (IOB160(I1:I2),1705,ERR=1790) X
 1705    FORMAT (G16.0)
         IF (IOB160(I1:I2).EQ.' ') GOTO 1791
C                                                 !ERROR
CD        WRITE (OUT,*) 'VALUE FOR VTCO: ',X
	 IF (.NOT.NEWTVC) THEN
		IF (X.NE.VTCO(IV,I)) THEN
		  WRITE (OUT,1707) COEFNM(IC),VTCO(IV,I),X
 1707		  FORMAT (' VTCO DIFFERENT THAN PREVIOUSLY DEFINED',
     &		    ' FOR COEF ',A8,'.  OLD, NEW VALUE =',2F6.1)
		  STOP 'VTCO DIFFERENT THAN PREVIOUSLY DEFINED'
	        ENDIF
         ELSE
	 	VTCO(IV,I)=X
CD		WRITE (OUT,*) 'VTCO(',IV,',',I,')=',VTCO(IV,I)
 	 ENDIF
 1740  CONTINUE
CD      WRITE (OUT,*) 'NVTEMP= ',NVTEMP
CD      WRITE (OUT,1708) COEFNM(IVTCO(IV)),(VTCO(IV,I),I=1,NVTEMP)
CD1708  FORMAT ('0VALUES FOR TEMPERATURE VARYING COEFFICIENT ',A8,':',
CD    &   3X,10F7.1)
       GOTO 1700
C
C  -     ERRORS
C
 1790  WRITE (OUT,1722) COEFNM(IVTCO(IV)),IOB160(1:80)
 1722  FORMAT (' DECODING ERROR IN LIST OF TEMP-VARYING COEF VALUES.',
     &   '  COEF=',A8,'.  INPUT LINE BELOW:'/' ',A)
       NERR=NERR+1
       GOTO 1700
 1791  WRITE (OUT,1723) COEFNM(IVTCO(IV)),IOB160(1:80)
 1723  FORMAT (' ERROR: NO. VALUES SPECIFIED < NVTEMP FOR COEF ',A8,
     &   '.  INPUT LINE BELOW:'/' ',A)
       NERR=NERR+1
       GOTO 1700
 1792  WRITE (OUT,1724) IOB160(1:80)
 1724  FORMAT (' ERROR OCCURRED IN ALIN16 AFTER VTCO COMMAND.  ALTERED'
     &  ,' INPUT LINE BELOW:'/' ',A)
       NERR=NERR+1
       GOTO 1700
C
C      .GROUP COMMAND
C
 1800  GNAME=IOB160(9:16)
       CALL MOVLF8 (GNAME)
       L=LENSTR(GNAME,8)
       IF (L.GT.4) THEN
              WRITE (OUT,*) 'WARNING:  GROUP NAME ',GNAME,' TRUNCATED',
     &          ' TO 4 CHARS'
              NWARN=NWARN+1
              GNAME(5:8)=' '
       ENDIF
       IF (NGRPS.GT.0) THEN
              DO 1810 I=1,NGRPS
              IF (GNAME(1:4).EQ.GRNAM(I)) THEN
C                    GROUP PREVIOUSLY DEFINED.
                     IND=-3
                     IGRP=I
                     GOTO 200
C                            			! READ IN SPECIES LIST
              ENDIF
 1810         CONTINUE
       ENDIF
C
C      NEW GROUP
C
       NGRPS=NGRPS+1
       IF (NGRPS.GT.MAXGRP) THEN
              WRITE (OUT,*) 'TOO MANY SPECIES GROUPS. MAX=',MAXGRP
              STOP 'TOO MANY SPECIES GROUPS'
       ENDIF
       GRNAM(NGRPS)=GNAME
C      ADD NEW VAR COEFS
       IF (AIRSHD) THEN
                NCV=NCOEFV+3
       ELSE
                NCV=NCOEFV+1
       ENDIF
       IF (NCV.GT.MAXCOV) THEN
		I=MAXCOV
		WRITE (OUT,*) 'TOO MANY VARIABLE COEFFICIENTS.  MAX =',I
		STOP 'TOO MANY VARIABLE COEFFICIENTS'
       ENDIF
C ---     COEF 'TOT.gname' USED FOR TOTAL AMOUNT OF ALL SPECIES IN THE GROUP
C         EMITTED OR INITIALLY PRESENT.  (FOR AIRSHED, NORMALLY IN UNITS OF
C         MOLES PER UNIT AREA PER DAY.  OTHERWISE, NORMALLY IN CONCENTRATION
C         UNITS.)
       IF (NCOEFV.GE.NCOC1) STOP 'TOO MANY VARIABLE COEFFICIENTS'
       NCOEFV=NCOEFV+1
       COEFNM(NCOEFV)='TOT.'
       COEFNM(NCOEFV)(5:8)=GNAME
       COEF(NCOEFV)=0.0
       ITOT(NGRPS)=NCOEFV
       IF (AIRSHD) THEN
C ---              COEF 'INI.gname' USED FOR FRACTION OF THE TOTAL OF SPECIES
C                  IN THIS GROUP WHICH ARE INITIALLY PRESENT.
                IF (NCOEFV.GT.NCOC1) THEN
			WRITE (ICRT,*) 'INCREASE MAXVCD (6).',
     &			 ' NCOC1, NCOEFV=',NCOEFV,NCOC1
			STOP 'TOO MANY VARIABLE COEFS.'
		ENDIF
                NCOEFV=NCOEFV+1
                COEFNM(NCOEFV)='INI.'
                COEFNM(NCOEFV)(5:8)=GNAME
                COEF(NCOEFV)=1.0
                IINI(NGRPS)=NCOEFV
C ---              COEF 'EMR.gname' USED FOR EMISSION RATE OF SPECIES IN THIS
C                  GROUP IN TERMS OF THE FRACTION OF THE TOTAL PER UNIT TIME.
		IF (NCOEFV.GT.NCOC1) THEN
			WRITE (ICRT,*) 'INCREASE MAXVCD (7).',
     &			 ' NCOC1, NCOEFV=',NCOEFV,NCOC1
			STOP 'TOO MANY VARIABLE COEFFICIENTS'
		ENDIF
                NCOEFV=NCOEFV+1
                COEFNM(NCOEFV)='EMR.'
                COEFNM(NCOEFV)(5:8)=GNAME
                COEF(NCOEFV)=0.0
                IEMR(NGRPS)=NCOEFV
       ENDIF
       IND=-3
       IGRP=NGRPS
       GOTO 200			! READ SPECIES LIST
C
C      .SGROUP (SPECIES GROUP) COMMAND
C
 1900	GNAME=IOB160(9:16)
	CALL MOVLF8 (GNAME)
	L=LENSTR(GNAME,8)
	IF (NSGRP.GT.0) THEN
		DO 1910 I=1,NSGRP
		IF (GNAME.EQ.NAME(SGRPID(I))(1:8)) THEN
			IGRP=SGRPID(I)
			GOTO 1920
		ENDIF
 1910		CONTINUE
	ENDIF
	IF (NSGRP.EQ.MAXSGP) STOP
     &	 'TOO MANY SPECIES GROUPS.  INCREASE MAXSGP'
	IF (NS.GT.MAXNS) STOP 'TOO MANY SPECIES.  INCREASE MAXNS'
	NS=NS+1
	NAME(NS)=GNAME//'        '
	SPTYP(NS)=3			! DUMMY SPECIES ADDED
	CONC0(NS)=0.0
	MWT(NS)=0.0
	CNO(NS)=0.0
	NNO(NS)=0
	NSGRP=NSGRP+1
	SGRPID(NSGRP)=NS
	IGRP=NS
 1920	CONTINUE
	IND=-5
	GOTO 200			! READ SPECIES LIST
C
C-------------------------------------------------------------------
C      NOW ALL REACTIONS INPUT. IRTOSR,ETC DEFINED.
C
 1999  EOF=.TRUE.
       WRITE (OUT,*) ' ERROR -- UNEXPECTED END-OF-FILE.'
       NERR=NERR+1
 2000  IF (.NOT.RXOPN) STOP 'PREP ABORTED.  NO REACTIONS.'
	IF (YESPRP) THEN
		IF (VCODFD) CLOSE (UNIT=UNIT1)
                WRITE (UNIT3) NEWRXN,1,' '
C                                                 !NEED DUMMY RXN LINE AT END

C              					  !FOR SAVERX TO READ FILE OK
		CLOSE (UNIT=UNIT3,STATUS='KEEP')
	ENDIF
C
C	WRITE NUMBERS OF REACTIONS, SPECIES, COEFS, ETC.  ABORT IF
C	BOUNDS EXCEEDED
C
	WRITE (OUT,2001) NRXN,NS,NCOEFV,1+NCOC2-NCOC1,NPHOTK
 2001	FORMAT (/I5,' REACTIONS,',I5,' SPECIES,',I5,' VARIABLE',
     &	 ' COEFFICIENTS,',I4,' CONSTANT COEFFICIENTS, AND',I4,
     &   ' PHOTOLYSIS FILES.')
C
	IF (NRXN.GT.MAXRXN) STOP 'TOO MANY REACTIONS'
	IF (NS.GT.MAXNS) STOP 'TOO MANY SPECIES'
	IF (NCOC2.GT.MAXCO) STOP 'TOO MANY CONSTANT COEFFICIENTS'
	IF (NCOEFV.GT.MAXCOV) STOP 'TOO MANY VARIABLE COEFFICIENTS'
	IF (NPHOTK.GT.MAXPHK) STOP 'TOO MANY PHOT. FILES'
C
	RETURN
	END
