	SUBROUTINE BASRCT (CDTU,CLCU,CLDU,PRMU,IND,O3KODE,
     &	 NMXC,MXCNAM,MXCONC)
C
C	SUMMARIZES RESULTS OF BASE CASE REACTIVITY CALCULATIONS.
C
C	ARGUMENTS (FIRST 3 UNIT NUMBERS FOR OPEN FILES)
C		CDTU = .CDA FILE FOR CALC
C		CLCU = .CLC FILE
C		CLDU = .CLD FILE
C		PRMU = .PRM FILE TO PUT SUMMARY RESULTS
C		IND  = STATUS.  -1 = ERROR.
C		O3KODE = 0 USE O3MAX FOR REACTIVITY
C			 1 USE O3-NO FOR REACTIVITY
C		NMXC = NO. MAX CONC'S TO SAVE (INCL O3)
C		MXCNAM = NAMES OF MAXC CONC'S
C		MXCONC = MAX, TIME MAX, FINAL, SUM CONC'S
C
C	READS BASE ID, CALC NO. FROM COMMAND LINE.  UPDATES
C	INCRCTDAT.CLC WITH THE DATA NEEDED BY INCRCT TO CALCULATE
C	REACTIVITIES, AND ALSO WITH DATA NEEDED TO CALCULATE
C	REACTIVITIES RELATIVE TO AMOUNT REACTED.
C
C	THE CHANNEL "TRACE" IS USED TO DETERMINE CORRECTION FACTOR
C	BETWEEN AMOUNT EMITTED AND AMOUNT AT END OF SIMULATION.
C	THAT MUST BE EMITTED BUT NOT REACT CHEMICALLY.
C
C	IT IS ASSUMED THAT THERE ARE CHANNELS T.3, T01, T03, T10,
C	T30, T1C, T3C, WHICH ARE DUMMY SPECIES WHICH REACT WITH RATE
C	CONSTANTS OF 3.E-2 TO 3.E-5 PPM-1 MIN-1.  THESE ARE USED TO 
C	CALCULATE 'AMOUNTS REACTED' AS A FUNCTION OF KOH.
C
	INTEGER CDTU,CLCU,CLDU,PRMU,IND,O3KODE,NMXC
	REAL MXCONC(4,NMXC)
	CHARACTER MXCNAM(NMXC)*5
C
C	BASE CASE RESULTS DATA. FOR A CALC AT A GIVEN C/N
C		MAXNPT=MAX NO DATA POINTS
C		TSTPRD = CONC'S OF T.3PROD, ECT.
C		CORFAC = CONC'S OF AVG OF (T.3+T.3PROD, ..., T3C+T3CPROD)
C		BASO3 = O3 CONC
C		BASNO = NO CONC
C		IO3DAT = INTO3 CONC
C		BASTIM = TIME
C		TO3M = TIME OF MAX O3/CORFAC
C
C
C	BUFFER FOR DATA READ FROM CALC
C
	PARAMETER (MAXCHN=250,MAXNPT=120)
	REAL CORFAC(MAXNPT),BASO3(MAXNPT),IO3DAT(MAXNPT),
     &	 BASIOH,BASNO(MAXNPT),BASTIM(MAXNPT),DATBUF(MAXCHN)
	CHARACTER*16 NAME(MAXCHN)
	COMMON /SCRTCHD/ DATBUF,CORFAC,BASO3,IO3DAT,BASNO,BASTIM
	COMMON /SCRTCHC/ NAME
C
C
	CHARACTER*40 CHRBUF
C
C	TEST SPECIES NAMES.
C
	PARAMETER (MINTST=7,MAXTST=16,NEWTST=MAXTST-MINTST)
	CHARACTER TSTNAM(MINTST)*3,TSTEMS(MAXTST)*4
	INTEGER INDTST(MAXTST)
	REAL TSTKOH(MINTST),TSTPRD(MAXNPT,MAXTST),RCTSAV(MAXTST)
C
	DATA TSTNAM/'T.3', 'T01', 'T03', 'T10', 'T30', 'T1C', 'T3C'/
	DATA TSTKOH /3.0E+2, 1.0E+3, 3.0E+3, 1.0E+4, 3.0E+4, 1.0E+5,
     &	 3.0E+5 /
	DATA TSTEMS/'0.3 ','1.0 ','3.0 ','10.0','30.0','100.','300.',
     &	 NEWTST*'    '/
	DATA INDTST/MAXTST*0/
C
	NTST=MINTST
C
C	INITIALIZE
C
C	READ IN 'HEADER' RECORDS
C
	READ (CDTU,'(2X,I5)',ERR=8030) NCHN
	IF (NCHN.GT.MAXCHN) THEN
		WRITE (6,*) 'INCREASE MAXCHN IN BASRCT, INCRCT, LOGCHG'
		IND=-1
		RETURN
	ENDIF
	READ (CDTU,'(8A11)',ERR=8030) (NAME(I),I=1,NCHN)
C
C	FIND WHICH CHANNELS ARE THOSE OF INTEREST (DONE ON FIRST CALL
C	ONLY.  OTHERS ASSUMED TO BE SAME MODEL.)
C
	INDO3=0
	INDNO=0
	INDTRC=0
	INDIO3=0
	INDIOH=0
C
	DO 1210 I=1,NCHN
	CHRBUF(1:8)=NAME(I)(1:8)
	IF (CHRBUF(1:3).EQ.'O3 ') THEN
		INDO3=I
	ELSEIF (CHRBUF(1:3).EQ.'NO ') THEN
		INDNO=I
	ELSEIF (CHRBUF(1:6).EQ.'TRACE ') THEN
		INDTRC=I
	ELSEIF (CHRBUF(1:6).EQ.'INTOH ') THEN
		INDIOH=I
	ELSEIF (CHRBUF(1:6).EQ.'INTO3 ') THEN
		INDIO3=I
	ELSEIF (CHRBUF(4:4).EQ.' ') THEN
		DO 1212 J=1,MINTST
		IF (CHRBUF(1:3).EQ.TSTNAM(J)) THEN
			INDTST(J)=I
			GOTO 1210
		ENDIF
 1212		CONTINUE
	ELSEIF (CHRBUF(1:2).EQ.'T_') THEN
		IF (NTST.EQ.MAXTST) STOP 'INCREASE MAXTST IN BASRCT.FOR'
		NTST=NTST+1
		INDTST(NTST)=I
		TSTEMS(NTST)=CHRBUF(3:6)
	ENDIF
 1210	CONTINUE
C
	IF (INDO3.EQ.0) THEN
		WRITE (6,*) 'NO "OZONE" CHANNEL'
		IND=-1
		RETURN
	ELSEIF (INDNO.EQ.0) THEN
		WRITE (6,*) 'NO "NO" CHANNEL'
		IND=-1
		RETURN
	ELSEIF (INDTRC.EQ.0) THEN
		WRITE (6,*) 'NO "TRACE" CHANNEL'
		IND=-1
		RETURN
C	ELSEIF (INDIO3.EQ.0) THEN
C		WRITE (6,*) 'NO "INTO3" CHANNEL'
C		IND=-1
C		RETURN
C	ELSEIF (INDIOH.EQ.0) THEN
C		WRITE (6,*) 'NO "INTOH" CHANNEL'
C		IND=-1
C		RETURN
	ENDIF
C
C
C	READ IN THE DATA
C	FIND MAXIMUM OZONE TIME.  (USED TO GET O3-NO)
C
	NPT=0
	O3M=0.0
	O3NOM=0.0
	IO3M=0
	IO3NOM=0
C
 1220	READ (CDTU,1221,END=1230,ERR=8030) T,(DATBUF(I),I=1,NCHN)
 1221	FORMAT (F10.2/(1PE10.3,7E11.3))
	IF (NPT.GE.MAXNPT) THEN
		WRITE (6,*)  'TOO MANY DATA POINTS'
		IND=-1
		RETURN
	ENDIF
	NPT=NPT+1
	BASTIM(NPT)=T
	BASO3(NPT)=DATBUF(INDO3)
	IF (INDIO3.NE.0) IO3DAT(NPT)=DATBUF(INDIO3)
	BASNO(NPT)=DATBUF(INDO3)-DATBUF(INDNO)
	IF (NPT.EQ.1) THEN
		O3MNO1=BASNO(1)
		BASNO(1)=0.0
	ELSE
		BASNO(NPT)=BASNO(NPT)-O3MNO1
	ENDIF
	IF (BASO3(NPT).GT.O3M) THEN
		O3M=BASO3(NPT)
		IO3M=NPT
	ENDIF
	IF (BASNO(NPT).GT.O3NOM) THEN
		O3NOM=BASNO(NPT)
		IO3NOM=NPT
	ENDIF
	CORFAC(NPT)=DATBUF(INDTRC)
C
	DO 1222 I=1,NTST
	IF (INDTST(I).NE.0) TSTPRD(NPT,I)=DATBUF(INDTRC)-
     &	 DATBUF(INDTST(I))
 1222	CONTINUE
	GOTO 1220
C
 1230	CLOSE (UNIT=CDTU)
C
C	ALL DATA READ.
C
	IF (INDIOH.NE.0) THEN
		BASIOH=DATBUF(INDIOH)
	ELSE
		BASIOH=0.0
	ENDIF
	IF (INDIO3.NE.0) THEN
		BASIO3=DATBUF(INDIO3)
	ELSE
		BASIO3=0.0
	ENDIF
C
C	UPDATE SAVED PARMS
C
	CORSAV=CORFAC(NPT)
	DO 1310 I=1,NTST
	IF (INDTST(I).NE.0) THEN
		RCTSAV(I)=TSTPRD(NPT,I)/CORSAV
	ELSE
		RCTSAV(I)=0.0
	ENDIF
 1310	CONTINUE
C
C
C	DONE WITH THIS CALC.  OUTPUT RESULTS TO PRMU
C
	WRITE (PRMU,2025) 'CORR    ',CORSAV
	WRITE (PRMU,2022) 'MAXO3   ',MXCONC(1,1)
	WRITE (PRMU,2021) 'TM-O3   ',MXCONC(2,1)
	WRITE (PRMU,2022) 'ENDO3   ',MXCONC(3,1)
	WRITE (PRMU,2022) 'SUMO3   ',MXCONC(4,1)
	IF (INDIO3.NE.0) WRITE (PRMU,2021) 'INTD-O3 ',BASIO3
	IF (INDIOH.NE.0) WRITE (PRMU,2025) 'INTD-OH ',BASIOH
	IF (NMXC.GT.1) THEN
		DO 2002 I=2,NMXC
		WRITE (PRMU,2025) 'MAX'//MXCNAM(I),MXCONC(1,I)
		IF (MXCONC(1,I).NE.0.0) WRITE (PRMU,2021) 
     &		 'TM-'//MXCNAM(I),MXCONC(2,I)
		WRITE (PRMU,2025) 'END'//MXCNAM(I),MXCONC(3,I)
		WRITE (PRMU,2025) 'SUM'//MXCNAM(I),MXCONC(4,I)
 2002		CONTINUE
	ENDIF
	WRITE (PRMU,2022) 'O3MNO   ',BASNO(IO3NOM)
	WRITE (PRMU,2021) 'TM-O3MNO',BASTIM(IO3NOM)
	WRITE (PRMU,2022) 'O3MAXSV  ',BASO3(IO3M)
	WRITE (PRMU,2021) 'TM-O3MAXS',BASTIM(IO3M)
	WRITE (PRMU,2021) 'TIME    ',BASTIM(NPT)
 2020	FORMAT (A8,I8)
 2021	FORMAT (A8,F12.3)
 2022	FORMAT (A8,F12.6)
 2025	FORMAT (A8,1PE12.4)
C
C	FIND FRACTIONS REACTED, AND OUTPUT THEM.
C
	JMIN=0
	DO 2030 J=1,MINTST
	IF (INDTST(J).NE.0) THEN
		WRITE (PRMU,2023) TSTKOH(J),RCTSAV(J)
 2023		FORMAT ('FR-KOH',1PE10.2,0PF9.5)
		IF (JMIN.EQ.0) THEN
			JMIN=J
		ELSEIF (TSTKOH(J).LT.TSTKOH(JMIN)) THEN
			JMIN=J
		ENDIF
	ENDIF
 2030	CONTINUE
	IF (NTST.GT.MINTST) THEN
		DO 2122 J=MINTST+1,NTST
 2122		WRITE (PRMU,2022) 'FR-'//TSTEMS(J)//' ',RCTSAV(J)
	ENDIF
C
C	CALCULATE INTOH FROM TST WITH LOWEST KOH
C
	IF (JMIN.NE.0) WRITE (PRMU,2025) 'INTOH   ',
     &	 -ALOG(1.0-RCTSAV(JMIN))/TSTKOH(JMIN)
C
C	DONE
C
	CLOSE (UNIT=PRMU)
	IND=0
C
C	WRITE HEADER INFO DATA ON CLCU, IF APPLICABLE
C
	IF (CLCU.EQ.0) RETURN
C
	IF (O3KODE.NE.1) THEN
		WRITE (CLCU,2090) 'O3max',MXCONC(1,1),
     &		 MXCONC(1,1)/CORSAV
	ELSE
		WRITE (CLCU,2090) 'O3-NO',BASNO(IO3M),
     &		 BASNO(IO3M)/CORSAV
	ENDIF
 2090	FORMAT (' TestHC    MaxO3   Cor-',A5,'   IncRct    MechRct',
     &   '  PctChg  CalNo  Added    KinRct'/'BASE',F14.6,F10.6,28X,I6)
	CLOSE (UNIT=CLCU)
C
C	WRITE DETAILED DATA ON CLDU, IF APPLICABLE
C
	IF (CLDU.EQ.0) RETURN
C
	IF (O3KODE.NE.1) THEN
		CHRBUF(1:5)='O3   '
	ELSE
		CHRBUF(1:5)='O3-NO'
	ENDIF
	IF (NMXC.EQ.1) THEN
		WRITE (CLDU,2096) 
		WRITE (CLDU,2098) CHRBUF(1:5),3,NPT,CORSAV,
     &		 MXCONC(1,1),BASIO3,BASIOH
	ELSE
		WRITE (CLDU,2096) ('MAX'//MXCNAM(I),I=2,NMXC),
     &		 ('END'//MXCNAM(I),I=1,NMXC),('SUM'//MXCNAM(I),I=1,NMXC)
		WRITE (CLDU,2098) CHRBUF(1:5),(2*NMXC)+3,NPT,CORSAV,
     &		 MXCONC(1,1),BASIO3,BASIOH,(MXCONC(1,I),I=2,NMXC),
     &		 (MXCONC(3,I),I=1,NMXC),(MXCONC(4,I),I=1,NMXC)
	ENDIF
 2096	FORMAT ('!--------------------------------------------------',
     &   '----------------------------'/'!ID(BAS) ADDED(NNPT) KINRCT',
     &   '(FAC) MAXO3       INTD-O3     INTD-OH ',120(:,4X,A8))
 2098	FORMAT ('!',8X,'T'/'!',8X,A5,1X,'(T)'/'!',8X,'INTO3 (T)'
     &   //'BASE',2I4,8X,1P120E12.5)
	WRITE (CLDU,'(8X,16F12.2)') (BASTIM(I),I=1,NPT)
	IF (O3KODE.NE.1) THEN
		WRITE (CLDU,2099) (BASO3(I),I=1,NPT)
	ELSE
		WRITE (CLDU,2099) (BASNO(I),I=1,NPT)
	ENDIF
	IF (INDIO3.NE.0) WRITE (CLDU,2099) (IO3DAT(I),I=1,NPT)
 2099	FORMAT (8X,1P16E12.5)
	CLOSE (UNIT=CLDU)
C
	RETURN
C
C	ERRORS
C
 8030	WRITE (6,*) 'Error reading calculation data'
	IND=-1
	CLOSE (UNIT=CDTU)
	RETURN
	END
