	SUBROUTINE LINFIT (N,X,Y,S,US,AI,UI)
C
C	FITS A LEAST SQUARES LINE TO DATA
C
C
C			AVERAGE DATA IN X, Y, WHERE N IS
C			DIMENSTIONS OF X,Y.
C			S, US = SLOPE AND UNCERTAINTY (1-SIGMA)
C			AI, UI = INTERCEPT AND UNCERTAINTY.
C
C
	REAL*4 X(N),Y(N),S,US,AI,UI,BUF(8),X0,Y0
	REAL*8 FN,X1,SX,SY,SXX,SYY,SXY,USY,AI0,S0
C
	LOGICAL STDIND
C
C	IF N TOO SMALL, UNC(SLOPE) SET TO -1, AND UNC(INT) CONTAINS N
C
	STDIND=.TRUE.
	IF (N.LE.1) THEN
		IF (N.EQ.1) THEN
			AI=Y(1)
		ELSE
			AI=0.0
		ENDIF
		S=0.0
		US=0.0
		UI=0.0
		RETURN
	ENDIF
C
C	INITIALIZE SUMS
C
	SX=0.0
	SY=0.0
	SXX=0.0
	SYY=0.0
	SXY=0.0
C
C	ADD ARRAY TO SUMS
C
	DO 1010 I=1,N
	XX=X(I)
	YY=Y(I)
	SX=SX+XX
	SY=SY+YY
	SXX=SXX+XX*XX
	SYY=SYY+YY*YY
 1010	SXY=SXY+XX*YY
C
C	CALCULATE SLOPE, INT.  IF NO RANGE IN X, SLOPE IS ZERO,
C	INTERCEPT IS AVERAGE OF Y
C
	FN=FLOAT(N)
	X1=FN*SXX-SX*SX
	IF (X1.EQ.0.0) THEN
		AI=SY/FN
		UI=(SYY-(FN*AI*AI))/(FN-1.)
		S=0.0
		US=0.0
		USY=0.0
	ELSE
		AI=(SXX*SY-SX*SXY)/X1
		S=(FN*SXY-SX*SY)/X1
		IF (N.EQ.2) THEN
			US=0.0
			UI=0.0
			USY=0.0
		ELSE
			USY=SYY-(((SY*SY*SXX) -(2.0*SXY*SX*SY) 
     &			 +(FN*SXY*SXY))/X1)
			IF (USY.GT.0.0) THEN
				USY=SQRT(USY/(FN-2.))
				US=USY*SQRT(FN/X1)
				UI=USY*SQRT(SXX/X1)
			ELSE
				USY=0.0
				US=0.0
				UI=0.0
			ENDIF
		ENDIF
	ENDIF
	RETURN
C
C
C	ENTRY TO RETURN DATA USED TO COMPUTE UNCERTAINTIES OF
C	POINTS
C
C	IND=1	= RETURN DATA TO CALLING PROGRAM
C	IND=2	= SET DATA TO THOSE SUPPLIED BY CALLING PROGRAM
C	IND=3	= SAME AS IND=1, BUT SETS STDIND SO THAT UNCERTAINTIES FROM
C		  LFTSY ARE -1 IF UNCERTAINTY CAN'T BE COMPUTED.
C	IND=4	= BUF IGNORED.  SETS STDIND
C		
C
	ENTRY LFTDAT (IND,BUF)
C
	IF (IND.EQ.1) THEN
		BUF(1)=SX
		BUF(2)=SY
		BUF(3)=SXX
		BUF(4)=SXY
		BUF(5)=SYY
		BUF(6)=USY
		BUF(7)=X1
		BUF(8)=FN
	ELSEIF (IND.EQ.2.OR.IND.EQ.3) THEN
		STDIND=(IND.NE.3)
		SX=BUF(1)
		SY=BUF(2)
		SXX=BUF(3)
		SXY=BUF(4)
		SYY=BUF(5)
		USY=BUF(6)
		X1=BUF(7)
		FN=BUF(8)
		IF (FN.EQ.0.0) THEN
			AI0=0.0
			S0=0.0
		ELSEIF (X1.EQ.0.0) THEN
			AI0=SY/FN
			S0=0.0
		ELSE
			AI0=(SXX*SY-SX*SXY)/X1
			S0=(FN*SXY-SX*SY)/X1
		ENDIF
	ELSEIF (IND.EQ.4) THEN
		STDIND=.FALSE.
	ENDIF
	RETURN
C
C	ENTRY TO COMPUTE A POINT AND ITS UNCERTANTY
C
	ENTRY LFTEST (X0,Y0,UYI)
C
	Y0=AI0+(S0*X0)
C
C	ENTRY TO COMPUTE UNCERTAINTY OF A POINT
C
C	ENTRY LFTSY (X0,UY,UYI)
	ENTRY LFTSY (X0,UYI)
C
	IF (FN.EQ.0.0) THEN
		UYI=-9.999E+9
		GOTO 800
	ELSEIF (FN.EQ.1.0) THEN
		UYI=-1.0
		GOTO 800
	ELSEIF (FN.EQ.2.0) THEN
		UYI=-2.0
		GOTO 800
	ENDIF
	XCOR2=(X0-(SX/FN))**2
	SXXC=SXX-SX*SX/FN
	IF (SXXC.EQ.0.0) THEN
		UYI=-1.0
		GOTO 800
	ENDIF
C	UY=UNCERTAINTY OF MEAN OF PREDICTED PT
C	UYI=UNCERTAINTY OF INDIVIDUAL PREDICTED Y

C	UY=USY*SQRT(1./FN + XCOR2/SXXC)
	UYI=USY*SQRT(1.+1./FN + XCOR2/SXXC)
	RETURN
C
  800	IF (STDIND) UYI=0.
	RETURN
	END	
