	PROGRAM CSVDAT
C
C	Outputs CSV files using GDT or CDA data.
C	Use: CSVDAT [file]
C	     file = input/output files; default=TMP
C	     input from file.IN, output to file.CSV
C
C	Input data:
C	OPT options ... options applicable for output from this point on
C		PAD nn (default PAD 100) ... pad output nn lines.
C		NOPAD  ... separate output by 1 blank line
C		CALCFMT ... calc output multiple channels with 1 time
C		STDFMT ... (default) output time, channel each chan
C		FIXWIDTH ... fixed width output -- force chan names 8 chars
C		NOFIXWIDTH ... (default) trim channel names
C		NOCSV ... no commas on output. Forces FIXWIDTH
C		HOUR ... Output times as hours (assumed to be min in files -- divide by 60)
C
C	GDT runid channel(s) ... input from [GDTuic]runid.GDT
C	CAL modelid runid channel(s) .. input from [CALuic]modelid\runid.CDA
C		channel(s) ... list of channels separated by blank or @file
C				with channel list, or * for list to follow
C				on subsequent lines ("." terminates).
C		each such line produces an output field, padded if PAD option
C
	PARAMETER (MAXCHN=10000,MAXNPT=2000,MAXOUT=50)
	LOGICAL CALCFMT,FIXWID,NOCSV,ERRIND,PAD,USEINST,USECHN,EOF,
     &	 FILEIN,USEHR
	INTEGER NPAD,CHANNO(MAXOUT),LOUTCH(MAXOUT),LOUTNM(MAXOUT)
	CHARACTER INLIN*240,INFILE*60,OUTNAM(MAXOUT)*20,FILNAM*80,
     &	 NAMEIN*20,INSTIN*20,OUTCHR(MAXOUT)*24,OUTLBL*60
C
	CHARACTER CALUIC*80,GDTUIC*80
	INTEGER LCALUC,LGDTUC
C
	CHARACTER RUNID*10,MODLID*8,NAMES(MAXCHN)*20
	INTEGER NPTS(MAXCHN)
	REAL TIMES(MAXNPT,MAXOUT),DATA(MAXNPT,MAXOUT),DATAI(MAXCHN)
C
C
	EOF=.FALSE.
	FILEIN=.TRUE.
	CALL GETARG (1,INFILE)
	IF (INFILE(1:2).EQ.'/?'.OR.INFILE(1:1).EQ.'?') THEN
		WRITE (6,*) 'Outputs CSV files using GDT or CDA data.'
		WRITE (6,*) 'Use: CSVDAT [file]'
		WRITE (6,*) '     file = input/output files; default=TMP'
		WRITE (6,*) '     input from file.IN, output to file.CSV'
		WRITE (6,*) 'Or: CSVDAT CMD line'
		WRITE (6,*) '     line = single input line to process'
		WRITE (6,*) '     no other input, output to TMP.CSV'
		CALL EXIT
	ELSEIF (INFILE.EQ.' ') THEN
		INFILE='TMP'
		LINFIL=3
	ELSEIF (INFILE.EQ.'CMD') THEN
		EOF=.TRUE.
		FILEIN=.FALSE.
		INFILE='TMP'
		LINFIL=3
	ELSE
		LINFIL=LNBLNK(INFILE)
	ENDIF
C
C	DEFAULTS
C
	PAD=.TRUE.
	NPAD=100
	CALCFMT=.FALSE.
	FIXWID=.FALSE.
	NOCSV=.FALSE.
	TIME0=0.0
	USEHR=.FALSE.
C
	CALUIC='.\'
	LCALUC=2
	GDTUIC='.\'
	LGDTUC=2
C
C	GET PARMS FROM MODELING.PRM
C
	OPEN (UNIT=1,FILE='MODELING.PRM',STATUS='UNKNOWN')
   10	READ (1,'(A)',END=11) INLIN
	IF (INLIN(1:4).EQ.'CAL=') THEN
		CALUIC=INLIN(5:)
		LCALUC=LNBLNK(CALUIC)
	ELSEIF (INLIN(1:4).EQ.'GDT=') THEN
		GDTUIC=INLIN(5:)
		LGDTUC=LNBLNK(GDTUIC)
	ENDIF
	GOTO 10
   11	CLOSE (UNIT=1)
C
C	OPEN INPUT AND OUTPUT FILES
C
	OPEN (UNIT=2,FILE=INFILE(1:LINFIL)//'.CSV',STATUS='UNKNOWN')
	IF (FILEIN) THEN
		OPEN (UNIT=1,FILE=INFILE(1:LINFIL)//'.IN',
     &		 STATUS='OLD',ACTION='READ',ERR=900)
	ELSE
		CALL GETARG (2,INLIN)
		IF (INLIN(1:1).EQ.' ') THEN
			WRITE (6,*) 'No command line given'
			CALL EXIT
		ENDIF
		
		GOTO 101
	ENDIF		
C
C	READ AND PROCESS NEXT INPUT LINE
C
  100	IF (EOF) GOTO 800
	READ (1,1,END=800) INLIN
    1	FORMAT (A)
  101	IF ((INLIN(1:1).EQ.' ').OR.(INLIN(1:1).EQ.'!')) THEN
		GOTO 100
C
	ELSEIF (INLIN(1:4).EQ.'OPT ') THEN
C		PROCESS OPTIONS
		IF (FILEIN) THEN
			CALL PARSE0 (10,INLIN,80)
		ELSE
			WRITE (6,*) 'Option input on '//
     &			 'command line not supported'	
			CLOSE (UNIT=2)
			CALL EXIT
		ENDIF
		IOPT=1
  110		IOPT=IOPT+1
		CALL PARSE1 (IOPT,NAMEIN,I,10,INLIN)
C
		IF (NAMEIN(1:1).EQ.' ') THEN
			GOTO 100
		ELSEIF (NAMEIN(1:4).EQ.'PAD ') THEN
			PAD=.TRUE.
			IOPT=IOPT+1
			CALL PARSEI (IOPT,NPAD,ERRIND,INLIN)
			IF (ERRIND.OR.(NPAD.LE.0)) THEN
				WRITE (6,*) 'Bad PAD input'
				GOTO 910
			ENDIF
		ELSEIF (NAMEIN(1:5).EQ.'NOPAD') THEN
			PAD=.FALSE.
			NPAD=MAXNPT
		ELSEIF (NAMEIN(1:7).EQ.'CALCFMT') THEN
			CALCFMT=.TRUE.
		ELSEIF (NAMEIN(1:6).EQ.'STDFMT') THEN
			CALCFMT=.FALSE.
		ELSEIF (NAMEIN(1:10).EQ.'FIXEDWIDTH') THEN
			FIXWID=.TRUE.
		ELSEIF (NAMEIN(1:12).EQ.'NOFIXEDWIDTH') THEN
			FIXWID=.FALSE.
		ELSEIF (NAMEIN(1:5).EQ.'NOCSV') THEN
			NOCSV=.TRUE.
		ELSEIF (NAMEIN(1:4).EQ.'HOUR') THEN
			USEHR=.TRUE.
		ELSE
			WRITE (6,*) 'Bad option: '//NAMEIN
			GOTO 910
		ENDIF
		IF (IOPT.LE.10) GOTO 110
		GOTO 100
C
	ELSEIF (INLIN(1:4).EQ.'CAL ') THEN
C		READ AND OUTPUT CALC INPUT
C
		IF (FILEIN) THEN
			CALL PARSE0 (20,INLIN,240)
			CALL PARSE1 (2,RUNID,LRUNID,10,INLIN)
			CALL PARSE1 (3,MODLID,LMODID,8,INLIN)
			IWRD=4
		ELSE
			CALL GETARG (3,RUNID)
			LRUNID=LNBLNK(RUNID)
			CALL GETARG (4,MODLID)
			LMODID=LNBLNK(MODLID)
			IWRD=5
		ENDIF
		IF (RUNID(1:1).EQ.' ') THEN
			WRITE (6,*) 'Run ID not given'
			GOTO 920
		ELSEIF (MODLID(1:1).EQ.' ') THEN
			WRITE (6,*) 'Model ID not given'
			GOTO 920
		ENDIF
		INMODE=1
C
	ELSEIF (INLIN(1:4).EQ.'GDT') THEN
C		READ AND OUTPUT GDT INPUT
C
		IF (FILEIN) THEN
			CALL PARSE0 (20,INLIN,240)
			CALL PARSE1 (2,RUNID,LRUNID,10,INLIN)
			IWRD=3
		ELSE
			CALL GETARG (3,RUNID)
			LRUNID=LNBLNK(RUNID)
			IWRD=4
		ENDIF
		IF (RUNID(1:1).EQ.' ') THEN
			WRITE (6,*) 'Run ID not given'
			GOTO 920
		ENDIF
		INMODE=2
C
	ELSE
		WRITE (6,*) 'Unrecognized input '
     &		 //INLIN(1:LNBLNK(INLIN))
		GOTO 980
	ENDIF
C
C	PROCESS NAME INPUTS FOR ALL TYPES OF INPUT
C
	IF (FILEIN) THEN
		CALL PARSE1 (IWRD,FILNAM,LFIL,80,INLIN)
	ELSE
		CALL GETARG (IWRD,FILNAM)
		LFIL=LNBLNK(FILNAM)
	ENDIF
	IF (FILNAM(1:1).EQ.' ') THEN
		WRITE (6,*) 'No channels listed'
		GOTO 920
	ELSEIF (FILNAM(1:1).EQ.'@') THEN
		FILNAM=FILNAM(2:)
		LFIL=LFIL-1
		OPEN (UNIT=3,FILE=FILNAM(1:LFIL),STATUS='OLD',
     &		 ACTION='READ',ERR=901)
		IFILE=3
		GOTO 130
	ELSEIF (FILEIN.AND.FILNAM(1:2).EQ.'* ') THEN
		IFILE=1
		GOTO 130
	ELSE
		NOUTCH=1
		OUTNAM(1)=FILNAM
		LOUTNM(1)=LNBLNK(OUTNAM(1))
		NPTS(1)=0
	ENDIF
C
C	READ CHANNEL NAMES FROM INPUT LINE
C
  120	IWRD=IWRD+1
	IF (FILEIN) THEN
		CALL PARSE1 (IWRD,NAMEIN,I,20,INLIN)
	ELSE
		CALL GETARG (IWRD,NAMEIN)
		I=LNBLNK(NAMEIN)
	ENDIF
	IF (NAMEIN(1:1).EQ.' ') GOTO 200
	IF (NOUTCH.EQ.MAXOUT) STOP "INCREASE MAXOUT IN CSVDAT.FOR"
	NOUTCH=NOUTCH+1
	OUTNAM(NOUTCH)=NAMEIN
	LOUTNM(NOUTCH)=I
	NPTS(NOUTCH)=0
	IF (IWRD.LT.20) GOTO 120
	GOTO 200
C
C	READ IN NAMES FROM LIST ON UNIT=IFILE
C
  130	NOUTCH=0
  132	READ (IFILE,1,END=134) NAMEIN
	IF ((NAMEIN(1:1).EQ.' '.OR.NAMEIN(1:1).EQ.'!')) THEN
		GOTO 132
	ELSEIF (NAMEIN(1:2).EQ.'. ') THEN
		GOTO 200
	ELSEIF (NOUTCH.LT.MAXOUT) THEN
		NOUTCH=NOUTCH+1
		OUTNAM(NOUTCH)=NAMEIN
		LOUTNM(NOUTCH)=LNBLNK(NAMEIN)
		NPTS(NOUTCH)=0
		GOTO 132
	ELSEIF (IFILE.EQ.1) THEN
		GOTO 132
	ELSE
		GOTO 134
	ENDIF
  134	IF (IFILE.EQ.1) THEN
		EOF=.TRUE.
	ELSE
		CLOSE (UNIT=IFILE)
	ENDIF
C
C	READ IN AND OUTPUT DATA DEPENDING ON TYPE
C
  200	IF (NOUTCH.EQ.0) THEN
		WRITE (6,*) 'No channels to output'
		GOTO 920
C
	ELSEIF (INMODE.EQ.1) THEN
C		CALCULATION DATA
C
		FILNAM=CALUIC(1:LCALUC)//MODLID(1:LMODID)//
     &		 '\'//RUNID(1:LRUNID)//'.CDA'
		LFIL=LCALUC+LMODID+LRUNID+5
		INQUIRE (FILE=FILNAM(1:LFIL),EXIST=ERRIND)
		IF (.NOT.ERRIND) GOTO 300
		OPEN (UNIT=3,FILE=FILNAM(1:LFIL),STATUS='OLD',
     &		 ACTION='READ')
C
		READ (3,'(2X,I5)',ERR=930) NCHN
		IF (NCHN.GT.MAXCHN) THEN
			WRITE (6,*) 'Input file has ',NCHN,
     &			 ' channels.  Max = ',MAXCHN
			GOTO 930
		ENDIF
		READ (3,'(8A11)',ERR=930) (NAMES(I),I=1,NCHN)
C
		DO 210 J=1,NOUTCH
		NAMEIN=OUTNAM(J)
		DO 212 I=1,NCHN
		IF (NAMES(I).EQ.NAMEIN) THEN
			CHANNO(J)=I
			GOTO 210
		ENDIF
  212		CONTINUE
		CHANNO(J)=0
  210		CONTINUE
C
		NPT=0
  220		READ (3,'(F10.2/(1PE10.3,7E11.3))',END=230,
     &		 ERR=930) T,(DATAI(I),I=1,NCHN)
		IF (USEHR) T=T/60.0
		NPT=NPT+1
C
		DO 222 J=1,NOUTCH
		IF (CHANNO(J).NE.0) THEN
			NPTS(J)=NPT
			TIMES(NPT,J)=T
			DATA(NPT,J)=DATAI(CHANNO(J))
		ENDIF
  222		CONTINUE
C
		IF (NPT.LT.NPAD) GOTO 220
  230		CLOSE (UNIT=3)
		NPTMAX=NPTS(1)
C
	ELSEIF (INMODE.EQ.2) THEN
C		GDT DATA
C
		FILNAM=GDTUIC(1:LGDTUC)//RUNID(1:LRUNID)//'.GDT'
		LFIL=LGDTUC+LRUNID+4
		MODLID='GDT'
		LMODID=3
C
		INQUIRE (FILE=FILNAM(1:LFIL),EXIST=ERRIND)
		IF (.NOT.ERRIND) GOTO 300
		OPEN (UNIT=3,FILE=FILNAM(1:LFIL),STATUS='OLD',ACTION='READ')
		READ (3,*) I
		IF (I.NE.3) THEN
			WRITE (6,*) 'Only type=3 GDT files supported.'
			GOTO 930
		ENDIF
		READ (3,*,ERR=930)
C
		DO 242 J=1,NOUTCH
		CHANNO(J)=0
  242		NPTS(J)=0
		NPTMAX=0
C
C		NEXT CHANNEL
C
  240		READ (3,1,END=280) INLIN
		IF (INLIN(1:1).EQ.' '.OR.INLIN(1:1).EQ.'!') GOTO 240
		CALL PARSE0 (3,INLIN,80)
		CALL PARSE1 (1,NAMEIN,I1,8,INLIN)
		CALL PARSE1 (2,INSTIN,I2,8,INLIN)
		CALL PARSI2 (3,IPRI,1,ERRIND,INLIN)
C
		USEINST=INSTIN(1:1).NE.' '
		IF (USEINST) THEN
			INSTIN=NAMEIN(1:I1)//';'//INSTIN(1:I2)
			I3=I1+I2+1
		ELSE
			INSTIN=NAMEIN
			I3=I1
		ENDIF
C
C		**NOTE** THIS NEEDS TO BE FIXED TO USE INST
		DO 255 J=1,NOUTCH
		IF (NAMEIN(1:I1).EQ.OUTNAM(J)(1:LOUTNM(J))) THEN
		ELSEIF (USEINST.AND.(INSTIN(1:I3).EQ.
     &		 OUTNAM(J)(1:LOUTNM(J)))) THEN
		ELSE
			GOTO 255
		ENDIF
		IF (NPTS(J).EQ.0) THEN
		ELSEIF (IPRI.LT.CHANNO(J)) THEN
		ELSE
			GOTO 255
		ENDIF
		NPTS(J)=0
		CHANNO(J)=IPRI
  250		READ (3,1,END=280) INLIN
		IF (INLIN(1:1).EQ.'.') GOTO 240
		IF (INLIN(1:1).EQ.'!') GOTO 250
		CALL PARSE0 (2,INLIN,80)
		CALL PARSER (1,T,ERRIND,INLIN)
		IF (ERRIND) GOTO 259
		IF (USEHR) T=T/60.0
		CALL PARSER (2,XDAT,ERRIND,INLIN)
		IF (ERRIND) GOTO 259
C		THIS VERSION PUTS LAST POINT BEFORE T=0 WITH NPT=1
		NPT=NPTS(J)
		IF (T.LE.0.0) THEN
			IF (NPT.EQ.0) THEN
				T=0.0
				NPT=1
			ELSEIF (NPT.EQ.1) THEN
				T=0.0
			ELSE
				GOTO 250
			ENDIF
		ELSEIF (NPT.EQ.MAXNPT) THEN
			GOTO 260
		ELSE
			NPT=NPT+1
		ENDIF
C
		TIMES(NPT,J)=T
		DATA(NPT,J)=XDAT
		NPTS(J)=NPT
		GOTO 250
C
  259		WRITE (6,*) 'Warning: Data for '//INSTIN(1:I3)//' in '//
     &		 RUNID(1:LRUNID)//' ignored.'
		WRITE (6,*) 'Bad line = '//INLIN(1:LNBLNK(INLIN))
		GOTO 260
  255		CONTINUE
C
C		SKIP CHANNEL
C
  260		READ (3,1,END=280) INLIN
		IF (INLIN(1:1).NE.'.') GOTO 260
		GOTO 240
C
C		EOF
C
  280		CLOSE (UNIT=3)
C
	ELSE
		STOP 'PROGRAM ERROR. BAD INMODE'
	ENDIF
C
C	OUTPUT DATA.  FIRST COMPRESS CHANNELS WITH MORE POINTS THAN NPAD
C
	NPTMAX=0
	DO 400 J=1,NOUTCH
	NPT=NPTS(J)
	IF (NPT.GT.NPAD) THEN
		ISKP=CEILING(FLOAT(NPTS(J))/NPAD)
		JPT=1
		DO 402 I=1+ISKP,NPT,ISKP
		JPT=JPT+1
		TIMES(JPT,J)=TIMES(I,J)
  402		DATA (JPT,J)=DATA(I,J)
		NPT=JPT
		NPTS(J)=JPT
	ENDIF
	IF (NPT.GT.NPTMAX) NPTMAX=NPT
  400	CONTINUE
C
	WRITE (2,513) RUNID(1:LRUNID),MODLID(1:LMODID)
  513	FORMAT (/A,',',A/)
	WRITE (2,511) (OUTNAM(I)(1:LOUTNM(I))//',',
     &	 I=1,NOUTCH)
  511	FORMAT (A,130(',',A))
	DO 500 IPT=1,NPTMAX
	DO 510 J=1,NOUTCH
	IF (NPTS(J).LT.IPT) THEN
		OUTCHR(J)=","
		LOUTCH(J)=1
	ELSE
		WRITE(OUTCHR(J),512) TIMES(IPT,J),DATA(IPT,J)
  512		FORMAT (F8.2,',',1PE11.3)
		LOUTCH(J)=20
	ENDIF
  510	CONTINUE
  500	WRITE (2,511) (OUTCHR(J)(1:LOUTCH(J)),J=1,NOUTCH)
	IF (PAD.AND.(NPTMAX.LT.NPAD)) THEN
		DO 514 I=NPTMAX+1,NPAD
  514		WRITE (2,*)
	ENDIF
C
	GOTO 100
C
C	OUTPUT IF DATA FILE NOT FOUND
C
  300	WRITE (2,513) RUNID(1:LRUNID),MODLID(1:LMODID)
	WRITE (6,1) 'No file,'//FILNAM(1:LFIL)
	WRITE (2,1) 'No file,'//FILNAM(1:LFIL)
	IF (PAD) THEN
		DO 301 I=1,NPAD
  301		WRITE (2,*)
	ENDIF
	GOTO 100
C
C	DONE
C
  800	IF (FILEIN) CLOSE (UNIT=1)
	CLOSE (UNIT=2)
	WRITE (6,*) 'File = '//INFILE(1:LINFIL)//'.CSV created.'
	OPEN (UNIT=1,FILE='CSVDAT.TMP',STATUS='UNKNOWN')
	WRITE (1,1) 'CSVDAT OK'
	CLOSE (UNIT=1)
	CALL EXIT (0)
C
C	ERRORS
C
  900	WRITE (6,*) 'File = '//INFILE(1:LINFIL)//'.IN does not exist'
	GOTO 990
  901	WRITE (6,*) 'File = '//FILNAM(1:LFIL)//'.IN does not exist'
	GOTO 980
  910	WRITE (6,*) 'Bad option input: '//INLIN(1:LNBLNK(INLIN))
	GOTO 980
  920	WRITE (6,*) 'Bad data input: '//INLIN(1:LNBLNK(INLIN))
	GOTO 980
  930	WRITE (6,*) 'Error reading file: '//FILNAM(1:LFIL)
	GOTO 970
C
  970	CLOSE (UNIT=3)
  980	CLOSE (UNIT=1)
	CLOSE (UNIT=2)
  990	OPEN (UNIT=1,FILE='CSVDAT.TMP',STATUS='UNKNOWN')
	WRITE (1,1) 'CSVDAT FAILED'
	CLOSE (UNIT=1)
	CALL EXIT (1)
	END